Class: Aws::DevOpsAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DevOpsAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-devopsagent/client.rb,
sig/client.rbs
Overview
An API client for DevOpsAgent. To construct a client, you need to configure a :region and :credentials.
client = Aws::DevOpsAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateServiceResponseSuccess, _CreateAgentSpaceResponseSuccess, _CreateAssetFileResponseSuccess, _CreateAssetResponseSuccess, _CreateBacklogTaskResponseSuccess, _CreateChatResponseSuccess, _CreatePrivateConnectionResponseSuccess, _CreateTriggerResponseSuccess, _DeleteAgentSpaceResponseSuccess, _DeleteAssetFileResponseSuccess, _DeleteAssetResponseSuccess, _DeletePrivateConnectionResponseSuccess, _DeleteTriggerResponseSuccess, _DeregisterServiceResponseSuccess, _DescribePrivateConnectionResponseSuccess, _DisassociateServiceResponseSuccess, _EnableOperatorAppResponseSuccess, _GetAccountUsageResponseSuccess, _GetAgentSpaceResponseSuccess, _GetAssetContentResponseSuccess, _GetAssetFileResponseSuccess, _GetAssetResponseSuccess, _GetAssociationResponseSuccess, _GetBacklogTaskResponseSuccess, _GetOperatorAppResponseSuccess, _GetRecommendationResponseSuccess, _GetServiceResponseSuccess, _GetTriggerResponseSuccess, _ListAgentSpacesResponseSuccess, _ListAssetFilesResponseSuccess, _ListAssetTypesResponseSuccess, _ListAssetVersionsResponseSuccess, _ListAssetsResponseSuccess, _ListAssociationsResponseSuccess, _ListBacklogTasksResponseSuccess, _ListChatsResponseSuccess, _ListExecutionsResponseSuccess, _ListGoalsResponseSuccess, _ListJournalRecordsResponseSuccess, _ListPendingMessagesResponseSuccess, _ListPrivateConnectionsResponseSuccess, _ListRecommendationsResponseSuccess, _ListServicesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTriggersResponseSuccess, _ListWebhooksResponseSuccess, _RegisterServiceResponseSuccess, _SendMessageResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAgentSpaceResponseSuccess, _UpdateApprovalActionResponseSuccess, _UpdateAssetFileResponseSuccess, _UpdateAssetResponseSuccess, _UpdateAssociationResponseSuccess, _UpdateBacklogTaskResponseSuccess, _UpdateGoalResponseSuccess, _UpdateOperatorAppIdpConfigResponseSuccess, _UpdatePrivateConnectionCertificateResponseSuccess, _UpdateRecommendationResponseSuccess, _UpdateTriggerResponseSuccess, _ValidateAwsAssociationsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description.
-
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new asset in the specified agent space.
-
#create_asset_file(params = {}) ⇒ Types::CreateAssetFileResponse
Creates a file in an asset.
-
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space.
-
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space.
-
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
-
#create_trigger(params = {}) ⇒ Types::CreateTriggerResponse
Creates a new Trigger in the specified agent space.
-
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace.
-
#delete_asset(params = {}) ⇒ Struct
Deletes an asset and all its files from the specified agent space.
-
#delete_asset_file(params = {}) ⇒ Struct
Deletes a file from an asset.
-
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection.
-
#delete_trigger(params = {}) ⇒ Struct
Deletes a Trigger from the specified agent space.
-
#deregister_service(params = {}) ⇒ Struct
Deregister a service.
-
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
-
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace.
-
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace.
-
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace.
-
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
-
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
-
#get_asset(params = {}) ⇒ Types::GetAssetResponse
Gets an asset from the specified agent space.
-
#get_asset_content(params = {}) ⇒ Types::GetAssetContentResponse
Gets an asset's content as a zip bundle.
-
#get_asset_file(params = {}) ⇒ Types::GetAssetFileResponse
Gets a file from an asset.
-
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
-
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id.
-
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow.
-
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID.
-
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it's unique identifier.
-
#get_trigger(params = {}) ⇒ Types::GetTriggerResponse
Gets a Trigger from the specified agent space.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
-
#list_asset_files(params = {}) ⇒ Types::ListAssetFilesResponse
Lists files in an asset.
-
#list_asset_types(params = {}) ⇒ Types::ListAssetTypesResponse
Lists the supported asset types.
-
#list_asset_versions(params = {}) ⇒ Types::ListAssetVersionsResponse
Lists versions of an asset in the specified agent space.
-
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Lists assets in the specified agent space.
-
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace.
-
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting.
-
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user's recent chat executions.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions.
-
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering.
-
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution.
-
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
-
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller's account.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space.
-
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
-
#list_triggers(params = {}) ⇒ Types::ListTriggersResponse
Lists Triggers in the specified agent space.
-
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association.
-
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service.
-
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
-
#update_approval_action(params = {}) ⇒ Types::UpdateApprovalActionResponse
Updates an approval request with the terminal decision (APPROVED or REJECTED).
-
#update_asset(params = {}) ⇒ Types::UpdateAssetResponse
Updates an asset in the specified agent space.
-
#update_asset_file(params = {}) ⇒ Types::UpdateAssetFileResponse
Updates a file in an asset.
-
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace.
-
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
-
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal.
-
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App.
-
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
-
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata.
-
#update_trigger(params = {}) ⇒ Types::UpdateTriggerResponse
Updates the status of an existing Trigger.
-
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
482 483 484 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 482 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4767 4768 4769 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4767 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4770 4771 4772 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4770 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace. It overwrites the existing association of the same service. Returns 201 Created on success.
90 |
# File 'sig/client.rbs', line 90
def associate_service: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 4754 4755 4756 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4740 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DevOpsAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-devopsagent' context[:gem_version] = '1.13.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description. Duplicate space names are allowed.
104 |
# File 'sig/client.rbs', line 104
def create_agent_space: (
|
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new asset in the specified agent space
120 |
# File 'sig/client.rbs', line 120
def create_asset: (
|
#create_asset_file(params = {}) ⇒ Types::CreateAssetFileResponse
Creates a file in an asset
135 |
# File 'sig/client.rbs', line 135
def create_asset_file: (
|
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space
154 |
# File 'sig/client.rbs', line 154
def create_backlog_task: (
|
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space
177 |
# File 'sig/client.rbs', line 177
def create_chat: (
|
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
199 |
# File 'sig/client.rbs', line 199
def create_private_connection: (
|
#create_trigger(params = {}) ⇒ Types::CreateTriggerResponse
Creates a new Trigger in the specified agent space
227 |
# File 'sig/client.rbs', line 227
def create_trigger: (
|
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
246 |
# File 'sig/client.rbs', line 246
def delete_agent_space: (
|
#delete_asset(params = {}) ⇒ Struct
Deletes an asset and all its files from the specified agent space
255 |
# File 'sig/client.rbs', line 255
def delete_asset: (
|
#delete_asset_file(params = {}) ⇒ Struct
Deletes a file from an asset
265 |
# File 'sig/client.rbs', line 265
def delete_asset_file: (
|
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection. The deletion is asynchronous and returns DELETE_IN_PROGRESS status.
278 |
# File 'sig/client.rbs', line 278
def delete_private_connection: (
|
#delete_trigger(params = {}) ⇒ Struct
Deletes a Trigger from the specified agent space
287 |
# File 'sig/client.rbs', line 287
def delete_trigger: (
|
#deregister_service(params = {}) ⇒ Struct
Deregister a service
297 |
# File 'sig/client.rbs', line 297
def deregister_service: (
|
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
317 |
# File 'sig/client.rbs', line 317
def describe_private_connection: (
|
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace
323 |
# File 'sig/client.rbs', line 323
def disable_operator_app: (
|
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
333 |
# File 'sig/client.rbs', line 333
def disassociate_service: (
|
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace
348 |
# File 'sig/client.rbs', line 348
def enable_operator_app: (
|
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
370 |
# File 'sig/client.rbs', line 370
def get_account_usage: (
|
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
380 |
# File 'sig/client.rbs', line 380
def get_agent_space: (
|
#get_asset(params = {}) ⇒ Types::GetAssetResponse
Gets an asset from the specified agent space
390 |
# File 'sig/client.rbs', line 390
def get_asset: (
|
#get_asset_content(params = {}) ⇒ Types::GetAssetContentResponse
Gets an asset's content as a zip bundle
403 |
# File 'sig/client.rbs', line 403
def get_asset_content: (
|
#get_asset_file(params = {}) ⇒ Types::GetAssetFileResponse
Gets a file from an asset
415 |
# File 'sig/client.rbs', line 415
def get_asset_file: (
|
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
428 |
# File 'sig/client.rbs', line 428
def get_association: (
|
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id
439 |
# File 'sig/client.rbs', line 439
def get_backlog_task: (
|
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow
453 |
# File 'sig/client.rbs', line 453
def get_operator_app: (
|
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID
463 |
# File 'sig/client.rbs', line 463
def get_recommendation: (
|
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it's unique identifier
476 |
# File 'sig/client.rbs', line 476
def get_service: (
|
#get_trigger(params = {}) ⇒ Types::GetTriggerResponse
Gets a Trigger from the specified agent space
486 |
# File 'sig/client.rbs', line 486
def get_trigger: (
|
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
498 |
# File 'sig/client.rbs', line 498
def list_agent_spaces: (
|
#list_asset_files(params = {}) ⇒ Types::ListAssetFilesResponse
Lists files in an asset
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
510 |
# File 'sig/client.rbs', line 510
def list_asset_files: (
|
#list_asset_types(params = {}) ⇒ Types::ListAssetTypesResponse
Lists the supported asset types
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
525 |
# File 'sig/client.rbs', line 525
def list_asset_types: (
|
#list_asset_versions(params = {}) ⇒ Types::ListAssetVersionsResponse
Lists versions of an asset in the specified agent space
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
537 |
# File 'sig/client.rbs', line 537
def list_asset_versions: (
|
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Lists assets in the specified agent space
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
551 |
# File 'sig/client.rbs', line 551
def list_assets: (
|
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
567 |
# File 'sig/client.rbs', line 567
def list_associations: (
|
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
581 |
# File 'sig/client.rbs', line 581
def list_backlog_tasks: (
|
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user's recent chat executions
604 |
# File 'sig/client.rbs', line 604
def list_chats: (
|
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
618 |
# File 'sig/client.rbs', line 618
def list_executions: (
|
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
632 |
# File 'sig/client.rbs', line 632
def list_goals: (
|
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
647 |
# File 'sig/client.rbs', line 647
def list_journal_records: (
|
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
665 |
# File 'sig/client.rbs', line 665
def list_pending_messages: (
|
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller's account.
676 |
# File 'sig/client.rbs', line 676
def list_private_connections: (
|
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space
686 |
# File 'sig/client.rbs', line 686
def list_recommendations: (
|
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
703 |
# File 'sig/client.rbs', line 703
def list_services: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
715 |
# File 'sig/client.rbs', line 715
def list_tags_for_resource: (
|
#list_triggers(params = {}) ⇒ Types::ListTriggersResponse
Lists Triggers in the specified agent space
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
726 |
# File 'sig/client.rbs', line 726
def list_triggers: (
|
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association
739 |
# File 'sig/client.rbs', line 739
def list_webhooks: (
|
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service
753 |
# File 'sig/client.rbs', line 753
def register_service: (
|
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution
896 |
# File 'sig/client.rbs', line 896
def send_message: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
922 |
# File 'sig/client.rbs', line 922
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
932 |
# File 'sig/client.rbs', line 932
def untag_resource: (
|
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
943 |
# File 'sig/client.rbs', line 943
def update_agent_space: (
|
#update_approval_action(params = {}) ⇒ Types::UpdateApprovalActionResponse
Updates an approval request with the terminal decision (APPROVED or REJECTED). A single operation handles both verbs via the action enum.
959 |
# File 'sig/client.rbs', line 959
def update_approval_action: (
|
#update_asset(params = {}) ⇒ Types::UpdateAssetResponse
Updates an asset in the specified agent space
978 |
# File 'sig/client.rbs', line 978
def update_asset: (
|
#update_asset_file(params = {}) ⇒ Types::UpdateAssetFileResponse
Updates a file in an asset
993 |
# File 'sig/client.rbs', line 993
def update_asset_file: (
|
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace. Present fields are fully replaced; absent fields are left unchanged. Returns 200 OK on success.
1013 |
# File 'sig/client.rbs', line 1013
def update_association: (
|
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
1026 |
# File 'sig/client.rbs', line 1026
def update_backlog_task: (
|
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal
1039 |
# File 'sig/client.rbs', line 1039
def update_goal: (
|
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App
1055 |
# File 'sig/client.rbs', line 1055
def update_operator_app_idp_config: (
|
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
1075 |
# File 'sig/client.rbs', line 1075
def update_private_connection_certificate: (
|
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata
1086 |
# File 'sig/client.rbs', line 1086
def update_recommendation: (
|
#update_trigger(params = {}) ⇒ Types::UpdateTriggerResponse
Updates the status of an existing Trigger
1100 |
# File 'sig/client.rbs', line 1100
def update_trigger: (
|
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
1112 |
# File 'sig/client.rbs', line 1112
def validate_aws_associations: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4760 4761 4762 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4760 def waiter_names [] end |