Module: Aws::DevOpsAgent::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-devopsagent/errors.rb
Overview
When DevOpsAgent returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::DevOpsAgent::Errors::ServiceError < Errors::ServiceError
You can rescue all DevOpsAgent errors using ServiceError:
begin
# do stuff
rescue Aws::DevOpsAgent::Errors::ServiceError
# rescues all DevOpsAgent API errors
end
## Request Context ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
## Error Classes
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AccessDeniedException, ConflictException, ContentSizeExceededException, IdentityCenterServiceException, InternalServerException, InvalidParameterException, ResourceNotFoundException, ServiceQuotaExceededException, ThrottlingException, ValidationException