Class: Aws::DevOpsAgent::Types::AWSConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Configuration for AWS monitor account integration, allowing AIDevOps to monitor AWS resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

AWS Account Id corresponding to provided resources.

Returns:

  • (String)


45
46
47
48
49
50
51
52
53
# File 'lib/aws-sdk-devopsagent/types.rb', line 45

class AWSConfiguration < Struct.new(
  :assumable_role_arn,
  :account_id,
  :account_type,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#account_typeString

Account Type 'monitor' for AIDevOps monitoring.

Returns:

  • (String)


45
46
47
48
49
50
51
52
53
# File 'lib/aws-sdk-devopsagent/types.rb', line 45

class AWSConfiguration < Struct.new(
  :assumable_role_arn,
  :account_id,
  :account_type,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#agent_elevated_role_arnString

Optional IAM role ARN to be assumed by AIDevOps for elevated directed actions on behalf of the customer. Used for mutating operations gated by elevatedActionsEnabled on the AgentSpace. When not provided, only non-elevated directed actions are available for this AWS account.

Returns:

  • (String)


45
46
47
48
49
50
51
52
53
# File 'lib/aws-sdk-devopsagent/types.rb', line 45

class AWSConfiguration < Struct.new(
  :assumable_role_arn,
  :account_id,
  :account_type,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#agent_elevated_role_arn_statusString

Validation status of the agentElevatedRoleArn. Updated asynchronously after the customer registers an elevated role. Possible values: PENDING_CONFIRMATION (validation in progress), VALID (role validated), INVALID (validation failed).

Returns:

  • (String)


45
46
47
48
49
50
51
52
53
# File 'lib/aws-sdk-devopsagent/types.rb', line 45

class AWSConfiguration < Struct.new(
  :assumable_role_arn,
  :account_id,
  :account_type,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#assumable_role_arnString

Role ARN to be assumed by AIDevOps to operate on behalf of customer.

Returns:

  • (String)


45
46
47
48
49
50
51
52
53
# File 'lib/aws-sdk-devopsagent/types.rb', line 45

class AWSConfiguration < Struct.new(
  :assumable_role_arn,
  :account_id,
  :account_type,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end