Class: Aws::DevOpsAgent::Types::AgentSpace
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::AgentSpace
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the AgentSpace.
-
#created_at ⇒ Time
The timestamp when the resource was created.
-
#description ⇒ String
The description of the AgentSpace.
-
#kms_key_arn ⇒ String
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that's used to encrypt resources.
-
#locale ⇒ String
The locale for the AgentSpace, which determines the language used in agent responses.
-
#name ⇒ String
The name of the AgentSpace.
-
#preferences ⇒ Hash<String,Boolean>
The preferences configured on the agent space.
-
#updated_at ⇒ Time
The timestamp when the resource was last updated.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the AgentSpace
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 236 class AgentSpace < Struct.new( :name, :description, :locale, :created_at, :updated_at, :kms_key_arn, :agent_space_id, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the resource was created.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 236 class AgentSpace < Struct.new( :name, :description, :locale, :created_at, :updated_at, :kms_key_arn, :agent_space_id, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the AgentSpace.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 236 class AgentSpace < Struct.new( :name, :description, :locale, :created_at, :updated_at, :kms_key_arn, :agent_space_id, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that's used to encrypt resources.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 236 class AgentSpace < Struct.new( :name, :description, :locale, :created_at, :updated_at, :kms_key_arn, :agent_space_id, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#locale ⇒ String
The locale for the AgentSpace, which determines the language used in agent responses.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 236 class AgentSpace < Struct.new( :name, :description, :locale, :created_at, :updated_at, :kms_key_arn, :agent_space_id, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the AgentSpace.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 236 class AgentSpace < Struct.new( :name, :description, :locale, :created_at, :updated_at, :kms_key_arn, :agent_space_id, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#preferences ⇒ Hash<String,Boolean>
The preferences configured on the agent space. Preferences that are not set take their default values.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 236 class AgentSpace < Struct.new( :name, :description, :locale, :created_at, :updated_at, :kms_key_arn, :agent_space_id, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the resource was last updated.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 236 class AgentSpace < Struct.new( :name, :description, :locale, :created_at, :updated_at, :kms_key_arn, :agent_space_id, :preferences) SENSITIVE = [:description] include Aws::Structure end |