Class: Aws::DevOpsAgent::Types::AssetFileBody

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Note:

AssetFileBody is a union - when making an API calls you must set exactly one of the members.

Note:

AssetFileBody is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AssetFileBody corresponding to the set member.

Content of an individual asset file

Direct Known Subclasses

Bytes, Text, Unknown

Defined Under Namespace

Classes: Bytes, Text, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bytesString

Binary file content

Returns:

  • (String)


337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/aws-sdk-devopsagent/types.rb', line 337

class AssetFileBody < Struct.new(
  :bytes,
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < AssetFileBody; end
  class Text < AssetFileBody; end
  class Unknown < AssetFileBody; end
end

#textString

Text file content

Returns:

  • (String)


337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/aws-sdk-devopsagent/types.rb', line 337

class AssetFileBody < Struct.new(
  :bytes,
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < AssetFileBody; end
  class Text < AssetFileBody; end
  class Unknown < AssetFileBody; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



337
338
339
# File 'lib/aws-sdk-devopsagent/types.rb', line 337

def unknown
  @unknown
end