Class: Aws::DevOpsAgent::Types::AssistantMessageBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Note:

AssistantMessageBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AssistantMessageBlock corresponding to the set member.

A block of content in an assistant message.

Direct Known Subclasses

Text, ToolUse, Unknown

Defined Under Namespace

Classes: Text, ToolUse, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textString

Text content from the assistant.

Returns:

  • (String)


481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-devopsagent/types.rb', line 481

class AssistantMessageBlock < Struct.new(
  :text,
  :tool_use,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < AssistantMessageBlock; end
  class ToolUse < AssistantMessageBlock; end
  class Unknown < AssistantMessageBlock; end
end

#tool_useHash, ...

Tool use request from the assistant.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-devopsagent/types.rb', line 481

class AssistantMessageBlock < Struct.new(
  :text,
  :tool_use,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < AssistantMessageBlock; end
  class ToolUse < AssistantMessageBlock; end
  class Unknown < AssistantMessageBlock; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



481
482
483
# File 'lib/aws-sdk-devopsagent/types.rb', line 481

def unknown
  @unknown
end