Class: Aws::DevOpsAgent::Types::AssociateServiceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::AssociateServiceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Output containing the newly created association and optional webhook configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association ⇒ Types::Association
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
-
#webhook ⇒ Types::GenericWebhook
Generic webhook configuration.
Instance Attribute Details
#association ⇒ Types::Association
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
274 275 276 277 278 279 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 274 class AssociateServiceOutput < Struct.new( :association, :webhook) SENSITIVE = [] include Aws::Structure end |
#webhook ⇒ Types::GenericWebhook
Generic webhook configuration
274 275 276 277 278 279 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 274 class AssociateServiceOutput < Struct.new( :association, :webhook) SENSITIVE = [] include Aws::Structure end |