Class: Aws::DevOpsAgent::Types::CreateAssetFileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for creating an asset file

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space containing the asset

Returns:

  • (String)


779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-devopsagent/types.rb', line 779

class CreateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#asset_idString

The unique identifier of the asset to create the file in

Returns:

  • (String)


779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-devopsagent/types.rb', line 779

class CreateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier used for idempotent asset file creation

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-devopsagent/types.rb', line 779

class CreateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contentTypes::AssetFileBody

The content of the file to create



779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-devopsagent/types.rb', line 779

class CreateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash, ...

Optional metadata describing this file

Returns:

  • (Hash, Array, String, Numeric, Boolean)


779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-devopsagent/types.rb', line 779

class CreateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path of the file within the asset

Returns:

  • (String)


779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-devopsagent/types.rb', line 779

class CreateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end