Class: Aws::DevOpsAgent::Types::CreateBacklogTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for creating a new backlog task

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space where the task will be created

Returns:

  • (String)


524
525
526
527
528
529
530
531
532
533
534
# File 'lib/aws-sdk-devopsagent/types.rb', line 524

class CreateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :reference,
  :task_type,
  :title,
  :description,
  :priority,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Client-provided token for idempotent operations

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


524
525
526
527
528
529
530
531
532
533
534
# File 'lib/aws-sdk-devopsagent/types.rb', line 524

class CreateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :reference,
  :task_type,
  :title,
  :description,
  :priority,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Optional detailed description of the task

Returns:

  • (String)


524
525
526
527
528
529
530
531
532
533
534
# File 'lib/aws-sdk-devopsagent/types.rb', line 524

class CreateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :reference,
  :task_type,
  :title,
  :description,
  :priority,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#priorityString

The priority level of the task

Returns:

  • (String)


524
525
526
527
528
529
530
531
532
533
534
# File 'lib/aws-sdk-devopsagent/types.rb', line 524

class CreateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :reference,
  :task_type,
  :title,
  :description,
  :priority,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#referenceTypes::ReferenceInput

Optional reference information for the task



524
525
526
527
528
529
530
531
532
533
534
# File 'lib/aws-sdk-devopsagent/types.rb', line 524

class CreateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :reference,
  :task_type,
  :title,
  :description,
  :priority,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_typeString

The type of task being created

Returns:

  • (String)


524
525
526
527
528
529
530
531
532
533
534
# File 'lib/aws-sdk-devopsagent/types.rb', line 524

class CreateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :reference,
  :task_type,
  :title,
  :description,
  :priority,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the backlog task

Returns:

  • (String)


524
525
526
527
528
529
530
531
532
533
534
# File 'lib/aws-sdk-devopsagent/types.rb', line 524

class CreateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :reference,
  :task_type,
  :title,
  :description,
  :priority,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end