Class: Aws::DevOpsAgent::Types::CreatePrivateConnectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Input for creating a new Private Connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#modeTypes::PrivateConnectionMode

Private Connection mode configuration.



1039
1040
1041
1042
1043
1044
1045
# File 'lib/aws-sdk-devopsagent/types.rb', line 1039

class CreatePrivateConnectionInput < Struct.new(
  :name,
  :mode,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Unique name for this Private Connection within the account.

Returns:

  • (String)


1039
1040
1041
1042
1043
1044
1045
# File 'lib/aws-sdk-devopsagent/types.rb', line 1039

class CreatePrivateConnectionInput < Struct.new(
  :name,
  :mode,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Tags to add to the Private Connection at creation time.

Returns:

  • (Hash<String,String>)


1039
1040
1041
1042
1043
1044
1045
# File 'lib/aws-sdk-devopsagent/types.rb', line 1039

class CreatePrivateConnectionInput < Struct.new(
  :name,
  :mode,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end