Class: Aws::DevOpsAgent::Types::CreateTriggerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for creating a new Trigger

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionHash, ...

The action the new Trigger performs when it fires

Returns:

  • (Hash, Array, String, Numeric, Boolean)


1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#agent_space_idString

The unique identifier for the agent space where the Trigger will be created

Returns:

  • (String)


1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier used for idempotent Trigger creation

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#conditionTypes::TriggerCondition

The condition that fires the new Trigger



1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The initial status of the Trigger

Returns:

  • (String)


1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

How the new Trigger fires

Returns:

  • (String)


1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end