Class: Aws::DevOpsAgent::Types::DeleteAssetFileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::DeleteAssetFileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for deleting an asset file
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset containing the file.
-
#path ⇒ String
The path of the file within the asset to delete.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
1201 1202 1203 1204 1205 1206 1207 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1201 class DeleteAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset containing the file
1201 1202 1203 1204 1205 1206 1207 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1201 class DeleteAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path of the file within the asset to delete
1201 1202 1203 1204 1205 1206 1207 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1201 class DeleteAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path) SENSITIVE = [] include Aws::Structure end |