Class: Aws::DevOpsAgent::Types::DeleteAssetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::DeleteAssetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for deleting an asset
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset to delete.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
1173 1174 1175 1176 1177 1178 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1173 class DeleteAssetRequest < Struct.new( :agent_space_id, :asset_id) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset to delete
1173 1174 1175 1176 1177 1178 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1173 class DeleteAssetRequest < Struct.new( :agent_space_id, :asset_id) SENSITIVE = [] include Aws::Structure end |