Class: Aws::DevOpsAgent::Types::DeleteTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::DeleteTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for deleting a Trigger
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the Trigger.
-
#trigger_id ⇒ String
The unique identifier of the Trigger to delete.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the Trigger
1463 1464 1465 1466 1467 1468 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1463 class DeleteTriggerRequest < Struct.new( :agent_space_id, :trigger_id) SENSITIVE = [] include Aws::Structure end |
#trigger_id ⇒ String
The unique identifier of the Trigger to delete
1463 1464 1465 1466 1467 1468 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1463 class DeleteTriggerRequest < Struct.new( :agent_space_id, :trigger_id) SENSITIVE = [] include Aws::Structure end |