Class: Aws::DevOpsAgent::Types::DescribePrivateConnectionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::DescribePrivateConnectionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Output containing the Private Connection details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_expiry_time ⇒ Time
The expiry time of the certificate associated with the Private Connection.
-
#dns_resolution ⇒ String
DNS resolution mode for the Private Connection’s resource gateway.
-
#failure_message ⇒ String
Message describing the reason for a failed Private Connection, if applicable.
-
#host_address ⇒ String
IP address or DNS name of the target resource.
-
#name ⇒ String
The name of the Private Connection.
-
#resource_configuration_id ⇒ String
The Resource Configuration ARN.
-
#resource_gateway_id ⇒ String
The service-managed Resource Gateway ARN.
-
#status ⇒ String
The status of the Private Connection.
-
#tags ⇒ Hash<String,String>
Tags associated with the Private Connection.
-
#type ⇒ String
The type of the Private Connection.
-
#vpc_id ⇒ String
VPC identifier of the service-managed Resource Gateway.
Instance Attribute Details
#certificate_expiry_time ⇒ Time
The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#dns_resolution ⇒ String
DNS resolution mode for the Private Connection’s resource gateway.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
Message describing the reason for a failed Private Connection, if applicable.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#host_address ⇒ String
IP address or DNS name of the target resource. Only present for service-managed Private Connections.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Private Connection.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_id ⇒ String
The Resource Configuration ARN. Only present for self-managed Private Connections.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_gateway_id ⇒ String
The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Private Connection.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags associated with the Private Connection.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the Private Connection.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1308 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |