Class: Aws::DevOpsAgent::Types::Execution
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::Execution
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Represents an execution instance with its lifecycle information
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing this execution.
-
#agent_sub_task ⇒ String
The specific subtask being executed by the agent.
-
#agent_type ⇒ String
The type of agent that performed this execution.
-
#created_at ⇒ Time
Timestamp when this execution was created.
-
#execution_id ⇒ String
The unique identifier for this execution.
-
#execution_status ⇒ String
The current status of this execution.
-
#parent_execution_id ⇒ String
The identifier of the parent execution, if this is a child execution.
-
#uid ⇒ String
The unique identifier for the user session associated with this execution.
-
#updated_at ⇒ Time
Timestamp when this execution was last updated.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing this execution
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |
#agent_sub_task ⇒ String
The specific subtask being executed by the agent
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |
#agent_type ⇒ String
The type of agent that performed this execution.
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp when this execution was created
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The unique identifier for this execution
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |
#execution_status ⇒ String
The current status of this execution
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |
#parent_execution_id ⇒ String
The identifier of the parent execution, if this is a child execution
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |
#uid ⇒ String
The unique identifier for the user session associated with this execution
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp when this execution was last updated
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1156 class Execution < Struct.new( :agent_space_id, :execution_id, :parent_execution_id, :agent_sub_task, :created_at, :updated_at, :execution_status, :agent_type, :uid) SENSITIVE = [] include Aws::Structure end |