Class: Aws::DevOpsAgent::Types::GetAccountUsageOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetAccountUsageOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#monthly_account_evaluation_hours ⇒ Types::UsageMetric
Monthly evaluation hours usage and limit for an account.
-
#monthly_account_investigation_hours ⇒ Types::UsageMetric
Monthly investigation hours usage and limit for an account.
-
#monthly_account_on_demand_hours ⇒ Types::UsageMetric
Monthly on-demand hours usage and limit for an account.
-
#monthly_account_system_learning_hours ⇒ Types::UsageMetric
Monthly system learning hours usage and limit for an account.
-
#usage_period_end_time ⇒ Time
The end time of the usage tracking period.
-
#usage_period_start_time ⇒ Time
The start time of the usage tracking period.
Instance Attribute Details
#monthly_account_evaluation_hours ⇒ Types::UsageMetric
Monthly evaluation hours usage and limit for an account
1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1237 class GetAccountUsageOutput < Struct.new( :monthly_account_investigation_hours, :monthly_account_evaluation_hours, :monthly_account_system_learning_hours, :monthly_account_on_demand_hours, :usage_period_start_time, :usage_period_end_time) SENSITIVE = [] include Aws::Structure end |
#monthly_account_investigation_hours ⇒ Types::UsageMetric
Monthly investigation hours usage and limit for an account
1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1237 class GetAccountUsageOutput < Struct.new( :monthly_account_investigation_hours, :monthly_account_evaluation_hours, :monthly_account_system_learning_hours, :monthly_account_on_demand_hours, :usage_period_start_time, :usage_period_end_time) SENSITIVE = [] include Aws::Structure end |
#monthly_account_on_demand_hours ⇒ Types::UsageMetric
Monthly on-demand hours usage and limit for an account
1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1237 class GetAccountUsageOutput < Struct.new( :monthly_account_investigation_hours, :monthly_account_evaluation_hours, :monthly_account_system_learning_hours, :monthly_account_on_demand_hours, :usage_period_start_time, :usage_period_end_time) SENSITIVE = [] include Aws::Structure end |
#monthly_account_system_learning_hours ⇒ Types::UsageMetric
Monthly system learning hours usage and limit for an account
1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1237 class GetAccountUsageOutput < Struct.new( :monthly_account_investigation_hours, :monthly_account_evaluation_hours, :monthly_account_system_learning_hours, :monthly_account_on_demand_hours, :usage_period_start_time, :usage_period_end_time) SENSITIVE = [] include Aws::Structure end |
#usage_period_end_time ⇒ Time
The end time of the usage tracking period
1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1237 class GetAccountUsageOutput < Struct.new( :monthly_account_investigation_hours, :monthly_account_evaluation_hours, :monthly_account_system_learning_hours, :monthly_account_on_demand_hours, :usage_period_start_time, :usage_period_end_time) SENSITIVE = [] include Aws::Structure end |
#usage_period_start_time ⇒ Time
The start time of the usage tracking period
1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1237 class GetAccountUsageOutput < Struct.new( :monthly_account_investigation_hours, :monthly_account_evaluation_hours, :monthly_account_system_learning_hours, :monthly_account_on_demand_hours, :usage_period_start_time, :usage_period_end_time) SENSITIVE = [] include Aws::Structure end |