Class: Aws::DevOpsAgent::Types::GetAssetContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetAssetContentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for getting an asset’s content as a zip bundle
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset.
-
#asset_version ⇒ Integer
The specific asset version to export.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
1750 1751 1752 1753 1754 1755 1756 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1750 class GetAssetContentRequest < Struct.new( :agent_space_id, :asset_id, :asset_version) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset
1750 1751 1752 1753 1754 1755 1756 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1750 class GetAssetContentRequest < Struct.new( :agent_space_id, :asset_id, :asset_version) SENSITIVE = [] include Aws::Structure end |
#asset_version ⇒ Integer
The specific asset version to export. If omitted, the latest version is returned.
1750 1751 1752 1753 1754 1755 1756 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1750 class GetAssetContentRequest < Struct.new( :agent_space_id, :asset_id, :asset_version) SENSITIVE = [] include Aws::Structure end |