Class: Aws::DevOpsAgent::Types::GetAssetFileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for getting an asset file

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space containing the asset

Returns:

  • (String)


1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-devopsagent/types.rb', line 1875

class GetAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :asset_version)
  SENSITIVE = []
  include Aws::Structure
end

#asset_idString

The unique identifier of the asset containing the file

Returns:

  • (String)


1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-devopsagent/types.rb', line 1875

class GetAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :asset_version)
  SENSITIVE = []
  include Aws::Structure
end

#asset_versionInteger

The specific asset version to retrieve the file from. If omitted, the latest version is returned.

Returns:

  • (Integer)


1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-devopsagent/types.rb', line 1875

class GetAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :asset_version)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path of the file within the asset to retrieve

Returns:

  • (String)


1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-devopsagent/types.rb', line 1875

class GetAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :asset_version)
  SENSITIVE = []
  include Aws::Structure
end