Class: Aws::DevOpsAgent::Types::GetAssetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetAssetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for getting an asset
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset to retrieve.
-
#asset_version ⇒ Integer
The specific version of the asset to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1838 class GetAssetRequest < Struct.new( :agent_space_id, :asset_id, :asset_version) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset to retrieve
1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1838 class GetAssetRequest < Struct.new( :agent_space_id, :asset_id, :asset_version) SENSITIVE = [] include Aws::Structure end |
#asset_version ⇒ Integer
The specific version of the asset to retrieve. If omitted, the latest version is returned.
1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1838 class GetAssetRequest < Struct.new( :agent_space_id, :asset_id, :asset_version) SENSITIVE = [] include Aws::Structure end |