Class: Aws::DevOpsAgent::Types::GetAssociationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetAssociationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Output containing the requested association details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association ⇒ Types::Association
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
Instance Attribute Details
#association ⇒ Types::Association
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
1310 1311 1312 1313 1314 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1310 class GetAssociationOutput < Struct.new( :association) SENSITIVE = [] include Aws::Structure end |