Class: Aws::DevOpsAgent::Types::GetBacklogTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetBacklogTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for retrieving a specific backlog task
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the task.
-
#task_id ⇒ String
The unique identifier of the task to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the task
2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2047 class GetBacklogTaskRequest < Struct.new( :agent_space_id, :task_id) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task to retrieve
2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2047 class GetBacklogTaskRequest < Struct.new( :agent_space_id, :task_id) SENSITIVE = [] include Aws::Structure end |