Class: Aws::DevOpsAgent::Types::GetRecommendationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetRecommendationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for retrieving a specific recommendation
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the recommendation.
-
#recommendation_id ⇒ String
The unique identifier for the recommendation to retrieve.
-
#recommendation_version ⇒ Integer
Specific version of the recommendation to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the recommendation
1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1409 class GetRecommendationRequest < Struct.new( :agent_space_id, :recommendation_id, :recommendation_version) SENSITIVE = [] include Aws::Structure end |
#recommendation_id ⇒ String
The unique identifier for the recommendation to retrieve
1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1409 class GetRecommendationRequest < Struct.new( :agent_space_id, :recommendation_id, :recommendation_version) SENSITIVE = [] include Aws::Structure end |
#recommendation_version ⇒ Integer
Specific version of the recommendation to retrieve. If not specified, returns the latest version.
1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1409 class GetRecommendationRequest < Struct.new( :agent_space_id, :recommendation_id, :recommendation_version) SENSITIVE = [] include Aws::Structure end |