Class: Aws::DevOpsAgent::Types::GetTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for getting a Trigger
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the Trigger.
-
#trigger_id ⇒ String
The unique identifier of the Trigger to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the Trigger
2201 2202 2203 2204 2205 2206 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2201 class GetTriggerRequest < Struct.new( :agent_space_id, :trigger_id) SENSITIVE = [] include Aws::Structure end |
#trigger_id ⇒ String
The unique identifier of the Trigger to retrieve
2201 2202 2203 2204 2205 2206 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2201 class GetTriggerRequest < Struct.new( :agent_space_id, :trigger_id) SENSITIVE = [] include Aws::Structure end |