Class: Aws::DevOpsAgent::Types::GitHubConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GitHubConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Configuration for GitHub repository integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_identifier ⇒ String
GitHub instance identifier (e.g., github.com or github.enterprise.com).
-
#owner ⇒ String
The GitHub repository owner name.
-
#owner_type ⇒ String
Type of GitHub repository owner.
-
#repo_id ⇒ String
Associated Github repo ID.
-
#repo_name ⇒ String
Associated Github repo name.
-
#runtime_role_arn ⇒ String
Optional role ARN that AIDevOps assumes at runtime for automatic verification testing and VPC connectivity on this association.
Instance Attribute Details
#instance_identifier ⇒ String
GitHub instance identifier (e.g., github.com or github.enterprise.com)
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2252 class GitHubConfiguration < Struct.new( :repo_name, :repo_id, :owner, :owner_type, :instance_identifier, :runtime_role_arn) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The GitHub repository owner name.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2252 class GitHubConfiguration < Struct.new( :repo_name, :repo_id, :owner, :owner_type, :instance_identifier, :runtime_role_arn) SENSITIVE = [] include Aws::Structure end |
#owner_type ⇒ String
Type of GitHub repository owner.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2252 class GitHubConfiguration < Struct.new( :repo_name, :repo_id, :owner, :owner_type, :instance_identifier, :runtime_role_arn) SENSITIVE = [] include Aws::Structure end |
#repo_id ⇒ String
Associated Github repo ID
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2252 class GitHubConfiguration < Struct.new( :repo_name, :repo_id, :owner, :owner_type, :instance_identifier, :runtime_role_arn) SENSITIVE = [] include Aws::Structure end |
#repo_name ⇒ String
Associated Github repo name
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2252 class GitHubConfiguration < Struct.new( :repo_name, :repo_id, :owner, :owner_type, :instance_identifier, :runtime_role_arn) SENSITIVE = [] include Aws::Structure end |
#runtime_role_arn ⇒ String
Optional role ARN that AIDevOps assumes at runtime for automatic verification testing and VPC connectivity on this association.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2252 class GitHubConfiguration < Struct.new( :repo_name, :repo_id, :owner, :owner_type, :instance_identifier, :runtime_role_arn) SENSITIVE = [] include Aws::Structure end |