Class: Aws::DevOpsAgent::Types::Goal
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::Goal
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Represents a goal with all its properties and metadata
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_arn ⇒ String
The unique identifier for the agent space containing this goal.
-
#content ⇒ Types::GoalContent
Content of the goal.
-
#created_at ⇒ Time
Timestamp when this goal was created.
-
#evaluation_schedule ⇒ Types::GoalSchedule
Goal Schedule.
-
#goal_id ⇒ String
The unique identifier for this goal.
-
#goal_type ⇒ String
Type of goal based on its origin.
-
#last_evaluated_at ⇒ Time
Timestamp when the goal was last evaluated.
-
#last_successful_task_id ⇒ String
ID of the most recent successful task associated with this goal.
-
#last_task_id ⇒ String
ID of the most recent task associated with this goal.
-
#status ⇒ String
Current status of the goal itself.
-
#title ⇒ String
The title of the goal.
-
#updated_at ⇒ Time
Timestamp when this goal was last updated.
-
#version ⇒ Integer
Version number for optimistic locking.
Instance Attribute Details
#agent_space_arn ⇒ String
The unique identifier for the agent space containing this goal
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::GoalContent
Content of the goal
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp when this goal was created
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#evaluation_schedule ⇒ Types::GoalSchedule
Goal Schedule. Allows to schedule the goal to run periodically, as well as disable a goal temporarily
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#goal_id ⇒ String
The unique identifier for this goal
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#goal_type ⇒ String
Type of goal based on its origin
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#last_evaluated_at ⇒ Time
Timestamp when the goal was last evaluated
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#last_successful_task_id ⇒ String
ID of the most recent successful task associated with this goal
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#last_task_id ⇒ String
ID of the most recent task associated with this goal
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Current status of the goal itself
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the goal
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp when this goal was last updated
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
Version number for optimistic locking
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 2195 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |