Class: Aws::DevOpsAgent::Types::ListBacklogTasksResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ListBacklogTasksResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Response structure containing a list of backlog tasks
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
Token for retrieving the next page of results, if more results are available.
-
#tasks ⇒ Array<Types::Task>
List of backlog tasks.
Instance Attribute Details
#next_token ⇒ String
Token for retrieving the next page of results, if more results are available
3143 3144 3145 3146 3147 3148 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3143 class ListBacklogTasksResponse < Struct.new( :tasks, :next_token) SENSITIVE = [] include Aws::Structure end |
#tasks ⇒ Array<Types::Task>
List of backlog tasks
3143 3144 3145 3146 3147 3148 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3143 class ListBacklogTasksResponse < Struct.new( :tasks, :next_token) SENSITIVE = [] include Aws::Structure end |