Class: Aws::DevOpsAgent::Types::ListChatsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for listing chats

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_id ⇒ String

The unique identifier for the agent space to list chats from.

Returns:

  • (String)


3172
3173
3174
3175
3176
3177
3178
3179
# File 'lib/aws-sdk-devopsagent/types.rb', line 3172

class ListChatsRequest < Struct.new(
  :agent_space_id,
  :user_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

Maximum number of results to return

Returns:

  • (Integer)


3172
3173
3174
3175
3176
3177
3178
3179
# File 'lib/aws-sdk-devopsagent/types.rb', line 3172

class ListChatsRequest < Struct.new(
  :agent_space_id,
  :user_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Token for pagination

Returns:

  • (String)


3172
3173
3174
3175
3176
3177
3178
3179
# File 'lib/aws-sdk-devopsagent/types.rb', line 3172

class ListChatsRequest < Struct.new(
  :agent_space_id,
  :user_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_id ⇒ String

The user identifier to list chats for. This field is deprecated and will be ignored — the service resolves user identity from the authenticated session.

Returns:

  • (String)


3172
3173
3174
3175
3176
3177
3178
3179
# File 'lib/aws-sdk-devopsagent/types.rb', line 3172

class ListChatsRequest < Struct.new(
  :agent_space_id,
  :user_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end