Class: Aws::DevOpsAgent::Types::ListRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for listing recommendations with filtering and pagination support

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_id ⇒ String

The unique identifier for the agent space containing the recommendations

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471

class ListRecommendationsRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :goal_id,
  :status,
  :priority,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#goal_id ⇒ String

Optional goal ID to filter recommendations by specific goal

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471

class ListRecommendationsRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :goal_id,
  :status,
  :priority,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#limit ⇒ Integer

Maximum number of recommendations to return in a single response

Returns:

  • (Integer)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471

class ListRecommendationsRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :goal_id,
  :status,
  :priority,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Token for retrieving the next page of results

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471

class ListRecommendationsRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :goal_id,
  :status,
  :priority,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#priority ⇒ String

Optional priority to filter recommendations by priority level

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471

class ListRecommendationsRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :goal_id,
  :status,
  :priority,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Optional status to filter recommendations by their current status

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471

class ListRecommendationsRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :goal_id,
  :status,
  :priority,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_id ⇒ String

Optional task ID to filter recommendations by specific task

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471

class ListRecommendationsRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :goal_id,
  :status,
  :priority,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end