Class: Aws::DevOpsAgent::Types::ListServicesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Input for listing registered services with optional filtering by service type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_service_type ⇒ String

Optional filter to list only services of a specific type.

Returns:

  • (String)


3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-devopsagent/types.rb', line 3520

class ListServicesInput < Struct.new(
  :max_results,
  :next_token,
  :filter_service_type)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

Maximum number of results to return in a single call.

Returns:

  • (Integer)


3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-devopsagent/types.rb', line 3520

class ListServicesInput < Struct.new(
  :max_results,
  :next_token,
  :filter_service_type)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Token for the next page of results.

Returns:

  • (String)


3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-devopsagent/types.rb', line 3520

class ListServicesInput < Struct.new(
  :max_results,
  :next_token,
  :filter_service_type)
  SENSITIVE = []
  include Aws::Structure
end