Class: Aws::DevOpsAgent::Types::ListServicesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Output containing a list of registered services and pagination token.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

Token to retrieve the next page of results, if there are more results.

Returns:

  • (String)


3541
3542
3543
3544
3545
3546
# File 'lib/aws-sdk-devopsagent/types.rb', line 3541

class ListServicesOutput < Struct.new(
  :next_token,
  :services)
  SENSITIVE = []
  include Aws::Structure
end

#services ⇒ Array<Types::RegisteredService>

List of registered services.

Returns:



3541
3542
3543
3544
3545
3546
# File 'lib/aws-sdk-devopsagent/types.rb', line 3541

class ListServicesOutput < Struct.new(
  :next_token,
  :services)
  SENSITIVE = []
  include Aws::Structure
end