Class: Aws::DevOpsAgent::Types::ListTriggersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for listing Triggers in an agent space

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_id ⇒ String

The unique identifier for the agent space whose Triggers should be listed

Returns:

  • (String)


3594
3595
3596
3597
3598
3599
3600
3601
# File 'lib/aws-sdk-devopsagent/types.rb', line 3594

class ListTriggersRequest < Struct.new(
  :agent_space_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in a single response

Returns:

  • (Integer)


3594
3595
3596
3597
3598
3599
3600
3601
# File 'lib/aws-sdk-devopsagent/types.rb', line 3594

class ListTriggersRequest < Struct.new(
  :agent_space_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Pagination token from a previous response to retrieve the next page of results

Returns:

  • (String)


3594
3595
3596
3597
3598
3599
3600
3601
# File 'lib/aws-sdk-devopsagent/types.rb', line 3594

class ListTriggersRequest < Struct.new(
  :agent_space_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Filter results to Triggers in this status

Returns:

  • (String)


3594
3595
3596
3597
3598
3599
3600
3601
# File 'lib/aws-sdk-devopsagent/types.rb', line 3594

class ListTriggersRequest < Struct.new(
  :agent_space_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end