Class: Aws::DevOpsAgent::Types::ListTriggersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ListTriggersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Response structure for listing Triggers
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::Trigger>
The list of Triggers.
-
#next_token ⇒ String
Pagination token to retrieve the next page of results.
Instance Attribute Details
#items ⇒ Array<Types::Trigger>
The list of Triggers
3615 3616 3617 3618 3619 3620 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3615 class ListTriggersResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token to retrieve the next page of results
3615 3616 3617 3618 3619 3620 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3615 class ListTriggersResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |