Class: Aws::DevOpsAgent::Types::MCPServerOAuth3LOConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::MCPServerOAuth3LOConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
OAuth 3-legged authorization configuration for MCP server.
Constant Summary collapse
- SENSITIVE =
[:client_id, :exchange_parameters, :client_secret]
Instance Attribute Summary collapse
-
#authorization_url ⇒ String
OAuth authorization URL for 3LO authentication.
-
#client_id ⇒ String
OAuth client ID for authenticating with the service.
-
#client_name ⇒ String
User friendly OAuth client name specified by end user.
-
#client_secret ⇒ String
OAuth client secret for authenticating with the service.
-
#exchange_parameters ⇒ Hash<String,String>
OAuth token exchange parameters for authenticating with the service.
-
#exchange_url ⇒ String
OAuth token exchange URL.
-
#return_to_endpoint ⇒ String
The endpoint to return to after OAuth flow completes (must be AWS console domain).
-
#scopes ⇒ Array<String>
OAuth scopes for 3LO authentication.
-
#support_code_challenge ⇒ Boolean
Whether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.
Instance Attribute Details
#authorization_url ⇒ String
OAuth authorization URL for 3LO authentication.
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |
#client_id ⇒ String
OAuth client ID for authenticating with the service.
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |
#client_name ⇒ String
User friendly OAuth client name specified by end user.
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |
#client_secret ⇒ String
OAuth client secret for authenticating with the service. Required for confidential clients or when PKCE is not supported. Optional for public clients using PKCE.
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |
#exchange_parameters ⇒ Hash<String,String>
OAuth token exchange parameters for authenticating with the service.
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |
#exchange_url ⇒ String
OAuth token exchange URL.
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |
#return_to_endpoint ⇒ String
The endpoint to return to after OAuth flow completes (must be AWS console domain)
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |
#scopes ⇒ Array<String>
OAuth scopes for 3LO authentication. The service will always request scope offline_access.
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |
#support_code_challenge ⇒ Boolean
Whether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.
3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3923 class MCPServerOAuth3LOConfig < Struct.new( :client_name, :client_id, :exchange_parameters, :return_to_endpoint, :authorization_url, :exchange_url, :client_secret, :support_code_challenge, :scopes) SENSITIVE = [:client_id, :exchange_parameters, :client_secret] include Aws::Structure end |