Class: Aws::DevOpsAgent::Types::ReferenceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Reference information linking a task to external systems - for input with validation

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

Association identifier of the external system

Returns:

  • (String)


4142
4143
4144
4145
4146
4147
4148
4149
4150
# File 'lib/aws-sdk-devopsagent/types.rb', line 4142

class ReferenceInput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#reference_idString

The unique identifier in the external system

Returns:

  • (String)


4142
4143
4144
4145
4146
4147
4148
4149
4150
# File 'lib/aws-sdk-devopsagent/types.rb', line 4142

class ReferenceInput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#reference_urlString

URL to access the reference in the external system

Returns:

  • (String)


4142
4143
4144
4145
4146
4147
4148
4149
4150
# File 'lib/aws-sdk-devopsagent/types.rb', line 4142

class ReferenceInput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#systemString

The name of the external system

Returns:

  • (String)


4142
4143
4144
4145
4146
4147
4148
4149
4150
# File 'lib/aws-sdk-devopsagent/types.rb', line 4142

class ReferenceInput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

Optional title for the reference

Returns:

  • (String)


4142
4143
4144
4145
4146
4147
4148
4149
4150
# File 'lib/aws-sdk-devopsagent/types.rb', line 4142

class ReferenceInput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end