Class: Aws::DevOpsAgent::Types::ReferenceOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Reference information linking a task to external systems - for output without validation

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

Association identifier of the external system

Returns:

  • (String)


3293
3294
3295
3296
3297
3298
3299
3300
3301
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293

class ReferenceOutput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#reference_idString

The unique identifier in the external system

Returns:

  • (String)


3293
3294
3295
3296
3297
3298
3299
3300
3301
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293

class ReferenceOutput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#reference_urlString

URL to access the reference in the external system

Returns:

  • (String)


3293
3294
3295
3296
3297
3298
3299
3300
3301
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293

class ReferenceOutput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#systemString

The name of the external system

Returns:

  • (String)


3293
3294
3295
3296
3297
3298
3299
3300
3301
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293

class ReferenceOutput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

Optional title for the reference

Returns:

  • (String)


3293
3294
3295
3296
3297
3298
3299
3300
3301
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293

class ReferenceOutput < Struct.new(
  :system,
  :title,
  :reference_id,
  :reference_url,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end