Class: Aws::DevOpsAgent::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
The requested resource could not be found.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed error message describing which resource was not found.
Instance Attribute Details
#message ⇒ String
Detailed error message describing which resource was not found.
3651 3652 3653 3654 3655 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3651 class ResourceNotFoundException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |