Class: Aws::DevOpsAgent::Types::SendMessageContentBlockDelta
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::SendMessageContentBlockDelta
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
SendMessageContentBlockDelta is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SendMessageContentBlockDelta corresponding to the set member.
Union of possible delta payloads within a content block delta event
Defined Under Namespace
Classes: JsonDelta, TextDelta, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#json_delta ⇒ Types::SendMessageJsonDelta
JSON delta for structured content blocks.
-
#text_delta ⇒ Types::SendMessageTextDelta
Text delta for text-based content blocks.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#json_delta ⇒ Types::SendMessageJsonDelta
JSON delta for structured content blocks
4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 4647 4648 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4637 class SendMessageContentBlockDelta < Struct.new( :text_delta, :json_delta, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class TextDelta < SendMessageContentBlockDelta; end class JsonDelta < SendMessageContentBlockDelta; end class Unknown < SendMessageContentBlockDelta; end end |
#text_delta ⇒ Types::SendMessageTextDelta
Text delta for text-based content blocks
4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 4647 4648 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4637 class SendMessageContentBlockDelta < Struct.new( :text_delta, :json_delta, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class TextDelta < SendMessageContentBlockDelta; end class JsonDelta < SendMessageContentBlockDelta; end class Unknown < SendMessageContentBlockDelta; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4637 4638 4639 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4637 def unknown @unknown end |