Class: Aws::DevOpsAgent::Types::SendMessageContentBlockStopEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::SendMessageContentBlockStopEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Event emitted when a content block is complete
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#index ⇒ Integer
Zero-based index of the content block.
-
#last ⇒ Boolean
Whether this is the final content block in the response.
-
#sequence_number ⇒ Integer
Event sequence number.
-
#text ⇒ String
The accumulated complete content text.
-
#type ⇒ String
The type of content in this block.
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type
3789 3790 3791 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3789 def event_type @event_type end |
#index ⇒ Integer
Zero-based index of the content block
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3789 class SendMessageContentBlockStopEvent < Struct.new( :index, :type, :text, :last, :sequence_number, :event_type) SENSITIVE = [] include Aws::Structure end |
#last ⇒ Boolean
Whether this is the final content block in the response
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3789 class SendMessageContentBlockStopEvent < Struct.new( :index, :type, :text, :last, :sequence_number, :event_type) SENSITIVE = [] include Aws::Structure end |
#sequence_number ⇒ Integer
Event sequence number
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3789 class SendMessageContentBlockStopEvent < Struct.new( :index, :type, :text, :last, :sequence_number, :event_type) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
The accumulated complete content text
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3789 class SendMessageContentBlockStopEvent < Struct.new( :index, :type, :text, :last, :sequence_number, :event_type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of content in this block
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3789 class SendMessageContentBlockStopEvent < Struct.new( :index, :type, :text, :last, :sequence_number, :event_type) SENSITIVE = [] include Aws::Structure end |