Class: Aws::DevOpsAgent::Types::SendMessageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for sending a chat message

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The agent space identifier

Returns:

  • (String)


3873
3874
3875
3876
3877
3878
3879
3880
3881
# File 'lib/aws-sdk-devopsagent/types.rb', line 3873

class SendMessageRequest < Struct.new(
  :agent_space_id,
  :execution_id,
  :content,
  :context,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end

#contentString

The user message content

Returns:

  • (String)


3873
3874
3875
3876
3877
3878
3879
3880
3881
# File 'lib/aws-sdk-devopsagent/types.rb', line 3873

class SendMessageRequest < Struct.new(
  :agent_space_id,
  :execution_id,
  :content,
  :context,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end

#contextTypes::SendMessageContext

Optional context for the message



3873
3874
3875
3876
3877
3878
3879
3880
3881
# File 'lib/aws-sdk-devopsagent/types.rb', line 3873

class SendMessageRequest < Struct.new(
  :agent_space_id,
  :execution_id,
  :content,
  :context,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end

#execution_idString

The execution identifier for the chat session

Returns:

  • (String)


3873
3874
3875
3876
3877
3878
3879
3880
3881
# File 'lib/aws-sdk-devopsagent/types.rb', line 3873

class SendMessageRequest < Struct.new(
  :agent_space_id,
  :execution_id,
  :content,
  :context,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

User identifier. This field is deprecated and will be ignored — the service resolves user identity from the authenticated session.

Returns:

  • (String)


3873
3874
3875
3876
3877
3878
3879
3880
3881
# File 'lib/aws-sdk-devopsagent/types.rb', line 3873

class SendMessageRequest < Struct.new(
  :agent_space_id,
  :execution_id,
  :content,
  :context,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end