Class: Aws::DevOpsAgent::Types::ServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Note:

ServiceConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

ServiceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ServiceConfiguration corresponding to the set member.

Union of all supported service configuration types. Each service has its own specific configuration structure.

Defined Under Namespace

Classes: Aws, Azure, Azuredevops, Dynatrace, EventChannel, Github, Gitlab, Mcpserver, Mcpserverdatadog, Mcpservergrafana, Mcpservernewrelic, Mcpserversigv4, Mcpserversplunk, Pagerduty, Remoteagent, Remoteagentsigv4, Servicenow, Slack, SourceAws, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#awsTypes::AWSConfiguration

AWS monitor account configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#azureTypes::AzureConfiguration

Azure subscription integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#azuredevopsTypes::AzureDevOpsConfiguration

Azure DevOps project integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#dynatraceTypes::DynatraceConfiguration

Dynatrace monitoring integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#event_channelTypes::EventChannelConfiguration

Event Channel instance integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#githubTypes::GitHubConfiguration

GitHub repository integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#gitlabTypes::GitLabConfiguration

GitLab project integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserverTypes::MCPServerConfiguration

MCP (Model Context Protocol) server integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserverdatadogTypes::MCPServerDatadogConfiguration

Datadog MCP server integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpservergrafanaTypes::MCPServerGrafanaConfiguration

Grafana MCP server integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpservernewrelicTypes::MCPServerNewRelicConfiguration

NewRelic instance integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserversigv4Types::MCPServerSigV4Configuration

SigV4-authenticated MCP server integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserversplunkTypes::MCPServerSplunkConfiguration

Splunk MCP server integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#pagerdutyTypes::PagerDutyConfiguration

PagerDuty integration configuration



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#remoteagentTypes::RemoteAgentConfiguration

Remote A2A agent integration configuration (token-based auth).



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#remoteagentsigv4Types::RemoteAgentSigV4Configuration

Remote A2A agent integration configuration (SigV4 auth).



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#servicenowTypes::ServiceNowConfiguration

ServiceNow instance integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#slackTypes::SlackConfiguration

Slack workspace integration configuration.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#source_awsTypes::SourceAwsConfiguration

AWS source account configuration for monitoring resources.



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :remoteagent,
  :remoteagentsigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Remoteagent < ServiceConfiguration; end
  class Remoteagentsigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5642
5643
5644
# File 'lib/aws-sdk-devopsagent/types.rb', line 5642

def unknown
  @unknown
end