Class: Aws::DevOpsAgent::Types::ServiceManagedInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Configuration for a service-managed Private Connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificateString

Certificate for the Private Connection.

Returns:

  • (String)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#dns_resolutionString

DNS resolution mode for the resource gateway. Defaults to PUBLIC when not set.

Returns:

  • (String)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#host_addressString

IP address or DNS name of the target resource.

Returns:

  • (String)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

IP address type of the service-managed Resource Gateway.

Returns:

  • (String)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#ipv4_addresses_per_eniInteger

Number of IPv4 addresses in each ENI for the service-managed Resource Gateway.

Returns:

  • (Integer)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#port_rangesArray<String>

TCP port ranges that a consumer can use to access the resource.

Returns:

  • (Array<String>)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

Security groups to attach to the service-managed Resource Gateway. If not specified, a default security group is created.

Returns:

  • (Array<String>)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

Subnets that the service-managed Resource Gateway will span.

Returns:

  • (Array<String>)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

VPC to create the service-managed Resource Gateway in.

Returns:

  • (String)


5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/aws-sdk-devopsagent/types.rb', line 5254

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end