Class: Aws::DevOpsAgent::Types::SlackConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::SlackConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Configuration for Slack workspace integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bidirectional ⇒ Types::SlackBidirectionalConfiguration
Optional bidirectional communication configuration.
-
#transmission_target ⇒ Types::SlackTransmissionTarget
Transmission targets for agent notifications.
-
#workspace_id ⇒ String
Associated Slack workspace ID.
-
#workspace_name ⇒ String
Associated Slack workspace name.
Instance Attribute Details
#bidirectional ⇒ Types::SlackBidirectionalConfiguration
Optional bidirectional communication configuration. Supply this configuration and set enabled to true so you can interact with the agent directly from Slack.
6214 6215 6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6214 class SlackConfiguration < Struct.new( :workspace_id, :workspace_name, :transmission_target, :bidirectional) SENSITIVE = [] include Aws::Structure end |
#transmission_target ⇒ Types::SlackTransmissionTarget
Transmission targets for agent notifications
6214 6215 6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6214 class SlackConfiguration < Struct.new( :workspace_id, :workspace_name, :transmission_target, :bidirectional) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
Associated Slack workspace ID
6214 6215 6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6214 class SlackConfiguration < Struct.new( :workspace_id, :workspace_name, :transmission_target, :bidirectional) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
Associated Slack workspace name
6214 6215 6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6214 class SlackConfiguration < Struct.new( :workspace_id, :workspace_name, :transmission_target, :bidirectional) SENSITIVE = [] include Aws::Structure end |