Class: Aws::DevOpsAgent::Types::SourceAwsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Configuration for AWS source account integration. Setting the role ARNs on this configuration requires the caller to have at least the iam:PassRole permission (see assumableRoleArn).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

AWS Account Id corresponding to provided resources.

Returns:

  • (String)


6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
# File 'lib/aws-sdk-devopsagent/types.rb', line 6287

class SourceAwsConfiguration < Struct.new(
  :account_id,
  :account_type,
  :assumable_role_arn,
  :external_id,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#account_typeString

Account Type 'source' for AIDevOps monitoring.

Returns:

  • (String)


6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
# File 'lib/aws-sdk-devopsagent/types.rb', line 6287

class SourceAwsConfiguration < Struct.new(
  :account_id,
  :account_type,
  :assumable_role_arn,
  :external_id,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#agent_elevated_role_arnString

Optional IAM role ARN to be assumed by AIDevOps for elevated directed actions on behalf of the customer. Used for mutating operations gated by elevatedActionsEnabled on the AgentSpace. When not provided, only non-elevated directed actions are available for this AWS account. Setting this role is subject to the same minimum iam:PassRole requirement described on assumableRoleArn.

Returns:

  • (String)


6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
# File 'lib/aws-sdk-devopsagent/types.rb', line 6287

class SourceAwsConfiguration < Struct.new(
  :account_id,
  :account_type,
  :assumable_role_arn,
  :external_id,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#agent_elevated_role_arn_statusString

Validation status of the agentElevatedRoleArn. Updated asynchronously after the customer registers an elevated role. Possible values: PENDING_CONFIRMATION (validation in progress), VALID (role validated), INVALID (validation failed).

Returns:

  • (String)


6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
# File 'lib/aws-sdk-devopsagent/types.rb', line 6287

class SourceAwsConfiguration < Struct.new(
  :account_id,
  :account_type,
  :assumable_role_arn,
  :external_id,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#assumable_role_arnString

Role ARN to be assumed by AIDevOps to operate on behalf of customer. To set this role ARN on AssociateService or UpdateAssociation, the caller must have at least the iam:PassRole permission on arn:aws:iam::<account-id>:role/* in the caller's own account, with the condition iam:PassedToService set to aidevops.amazonaws.com. A broader iam:PassRole grant also satisfies this requirement.

Returns:

  • (String)


6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
# File 'lib/aws-sdk-devopsagent/types.rb', line 6287

class SourceAwsConfiguration < Struct.new(
  :account_id,
  :account_type,
  :assumable_role_arn,
  :external_id,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end

#external_idString

External ID for additional security when assuming the role. Used to prevent the confused deputy problem.

Returns:

  • (String)


6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
# File 'lib/aws-sdk-devopsagent/types.rb', line 6287

class SourceAwsConfiguration < Struct.new(
  :account_id,
  :account_type,
  :assumable_role_arn,
  :external_id,
  :agent_elevated_role_arn,
  :agent_elevated_role_arn_status)
  SENSITIVE = []
  include Aws::Structure
end