Class: Aws::DevOpsAgent::Types::UpdateAgentSpaceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateAgentSpaceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Output containing the updated AgentSpace.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space ⇒ Types::AgentSpace
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Instance Attribute Details
#agent_space ⇒ Types::AgentSpace
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
4726 4727 4728 4729 4730 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4726 class UpdateAgentSpaceOutput < Struct.new( :agent_space) SENSITIVE = [] include Aws::Structure end |