Class: Aws::DevOpsAgent::Types::UpdateAssetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateAssetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for updating an asset
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset to update.
-
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset update.
-
#content ⇒ Types::AssetContent
Optional content update.
-
#metadata ⇒ Hash, ...
Metadata fields to update.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
6441 6442 6443 6444 6445 6446 6447 6448 6449 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6441 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset to update
6441 6442 6443 6444 6445 6446 6447 6448 6449 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6441 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset update
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6441 6442 6443 6444 6445 6446 6447 6448 6449 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6441 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::AssetContent
Optional content update. A single file adds or replaces one file; a zip replaces all files; a sourceUrl re-syncs from the original source.
6441 6442 6443 6444 6445 6446 6447 6448 6449 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6441 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash, ...
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
6441 6442 6443 6444 6445 6446 6447 6448 6449 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6441 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |