Class: Aws::DevOpsAgent::Types::UpdateAssociationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Output containing the updated association and optional webhook configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associationTypes::Association

Represents a service association within an AgentSpace, defining how the agent interacts with external services.

Returns:



4911
4912
4913
4914
4915
4916
# File 'lib/aws-sdk-devopsagent/types.rb', line 4911

class UpdateAssociationOutput < Struct.new(
  :association,
  :webhook)
  SENSITIVE = []
  include Aws::Structure
end

#webhookTypes::GenericWebhook

Generic webhook configuration



4911
4912
4913
4914
4915
4916
# File 'lib/aws-sdk-devopsagent/types.rb', line 4911

class UpdateAssociationOutput < Struct.new(
  :association,
  :webhook)
  SENSITIVE = []
  include Aws::Structure
end