Class: Aws::DevOpsAgent::Types::UpdateBacklogTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateBacklogTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for updating a task
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the task.
-
#client_token ⇒ String
Client-provided token for idempotent operations.
-
#task_id ⇒ String
The unique identifier of the task to update.
-
#task_status ⇒ String
Updated task status.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the task
5883 5884 5885 5886 5887 5888 5889 5890 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5883 class UpdateBacklogTaskRequest < Struct.new( :agent_space_id, :task_id, :task_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Client-provided token for idempotent operations
**A suitable default value is auto-generated.** You should normally not need to pass this option.
5883 5884 5885 5886 5887 5888 5889 5890 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5883 class UpdateBacklogTaskRequest < Struct.new( :agent_space_id, :task_id, :task_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task to update
5883 5884 5885 5886 5887 5888 5889 5890 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5883 class UpdateBacklogTaskRequest < Struct.new( :agent_space_id, :task_id, :task_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#task_status ⇒ String
Updated task status
5883 5884 5885 5886 5887 5888 5889 5890 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5883 class UpdateBacklogTaskRequest < Struct.new( :agent_space_id, :task_id, :task_status, :client_token) SENSITIVE = [] include Aws::Structure end |