Class: Aws::DevOpsAgent::Types::UpdateGoalRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for updating a goal

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space containing the goal

Returns:

  • (String)


4848
4849
4850
4851
4852
4853
4854
4855
# File 'lib/aws-sdk-devopsagent/types.rb', line 4848

class UpdateGoalRequest < Struct.new(
  :agent_space_id,
  :goal_id,
  :evaluation_schedule,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Client-provided token for idempotent operations

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


4848
4849
4850
4851
4852
4853
4854
4855
# File 'lib/aws-sdk-devopsagent/types.rb', line 4848

class UpdateGoalRequest < Struct.new(
  :agent_space_id,
  :goal_id,
  :evaluation_schedule,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_scheduleTypes::GoalScheduleInput

Update goal schedule state



4848
4849
4850
4851
4852
4853
4854
4855
# File 'lib/aws-sdk-devopsagent/types.rb', line 4848

class UpdateGoalRequest < Struct.new(
  :agent_space_id,
  :goal_id,
  :evaluation_schedule,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#goal_idString

The unique identifier of the goal to update

Returns:

  • (String)


4848
4849
4850
4851
4852
4853
4854
4855
# File 'lib/aws-sdk-devopsagent/types.rb', line 4848

class UpdateGoalRequest < Struct.new(
  :agent_space_id,
  :goal_id,
  :evaluation_schedule,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end