Class: Aws::DevOpsAgent::Types::UpdatePrivateConnectionCertificateOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdatePrivateConnectionCertificateOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Output containing the updated Private Connection summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_expiry_time ⇒ Time
The expiry time of the certificate associated with the Private Connection.
-
#dns_resolution ⇒ String
DNS resolution mode for the Private Connection’s resource gateway.
-
#failure_message ⇒ String
Message describing the reason for a failed Private Connection update, if applicable.
-
#host_address ⇒ String
IP address or DNS name of the target resource.
-
#name ⇒ String
The name of the Private Connection.
-
#resource_configuration_id ⇒ String
The Resource Configuration ARN.
-
#resource_gateway_id ⇒ String
The service-managed Resource Gateway ARN.
-
#status ⇒ String
The status of the Private Connection.
-
#type ⇒ String
The type of the Private Connection.
-
#vpc_id ⇒ String
VPC identifier of the service-managed Resource Gateway.
Instance Attribute Details
#certificate_expiry_time ⇒ Time
The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#dns_resolution ⇒ String
DNS resolution mode for the Private Connection’s resource gateway.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
Message describing the reason for a failed Private Connection update, if applicable.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#host_address ⇒ String
IP address or DNS name of the target resource. Only present for service-managed Private Connections.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Private Connection.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_id ⇒ String
The Resource Configuration ARN. Only present for self-managed Private Connections.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#resource_gateway_id ⇒ String
The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Private Connection.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the Private Connection.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6061 class UpdatePrivateConnectionCertificateOutput < Struct.new( :name, :type, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :status, :certificate_expiry_time, :dns_resolution, :failure_message) SENSITIVE = [] include Aws::Structure end |