Class: Aws::DevOpsAgent::Types::UpdateRecommendationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for updating an existing recommendation

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_contextString

Additional context for recommendation

Returns:

  • (String)


5012
5013
5014
5015
5016
5017
5018
5019
5020
# File 'lib/aws-sdk-devopsagent/types.rb', line 5012

class UpdateRecommendationRequest < Struct.new(
  :agent_space_id,
  :recommendation_id,
  :status,
  :additional_context,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#agent_space_idString

The unique identifier for the agent space containing the recommendation

Returns:

  • (String)


5012
5013
5014
5015
5016
5017
5018
5019
5020
# File 'lib/aws-sdk-devopsagent/types.rb', line 5012

class UpdateRecommendationRequest < Struct.new(
  :agent_space_id,
  :recommendation_id,
  :status,
  :additional_context,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token that ensures idempotency of the request

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


5012
5013
5014
5015
5016
5017
5018
5019
5020
# File 'lib/aws-sdk-devopsagent/types.rb', line 5012

class UpdateRecommendationRequest < Struct.new(
  :agent_space_id,
  :recommendation_id,
  :status,
  :additional_context,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_idString

The unique identifier for the recommendation to update

Returns:

  • (String)


5012
5013
5014
5015
5016
5017
5018
5019
5020
# File 'lib/aws-sdk-devopsagent/types.rb', line 5012

class UpdateRecommendationRequest < Struct.new(
  :agent_space_id,
  :recommendation_id,
  :status,
  :additional_context,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Current status of the recommendation

Returns:

  • (String)


5012
5013
5014
5015
5016
5017
5018
5019
5020
# File 'lib/aws-sdk-devopsagent/types.rb', line 5012

class UpdateRecommendationRequest < Struct.new(
  :agent_space_id,
  :recommendation_id,
  :status,
  :additional_context,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end