Class: Aws::DevOpsAgent::Types::UpdateTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for updating a Trigger
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the Trigger.
-
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent Trigger update.
-
#status ⇒ String
The new status for the Trigger.
-
#trigger_id ⇒ String
The unique identifier of the Trigger to update.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the Trigger
6809 6810 6811 6812 6813 6814 6815 6816 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6809 class UpdateTriggerRequest < Struct.new( :agent_space_id, :trigger_id, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent Trigger update
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6809 6810 6811 6812 6813 6814 6815 6816 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6809 class UpdateTriggerRequest < Struct.new( :agent_space_id, :trigger_id, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The new status for the Trigger
6809 6810 6811 6812 6813 6814 6815 6816 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6809 class UpdateTriggerRequest < Struct.new( :agent_space_id, :trigger_id, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#trigger_id ⇒ String
The unique identifier of the Trigger to update
6809 6810 6811 6812 6813 6814 6815 6816 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6809 class UpdateTriggerRequest < Struct.new( :agent_space_id, :trigger_id, :status, :client_token) SENSITIVE = [] include Aws::Structure end |