Class: Aws::DevOpsAgent::Types::UserMessageBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UserMessageBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
UserMessageBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserMessageBlock corresponding to the set member.
A block of content in a user message.
Defined Under Namespace
Classes: Text, ToolResult, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
Text content from the user.
-
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ String
Text content from the user.
7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 7227 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 7227 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7227 7228 7229 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 7227 def unknown @unknown end |