Class: Aws::DevOpsAgent::Types::ValidationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

The input fails to satisfy the constraints specified by the service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_listArray<Types::ValidationExceptionField>

A list of specific failures encountered while validating the input. A member can appear in this list more than once if it failed to satisfy multiple constraints.



7324
7325
7326
7327
7328
7329
# File 'lib/aws-sdk-devopsagent/types.rb', line 7324

class ValidationException < Struct.new(
  :message,
  :field_list)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A summary of the validation failure.

Returns:

  • (String)


7324
7325
7326
7327
7328
7329
# File 'lib/aws-sdk-devopsagent/types.rb', line 7324

class ValidationException < Struct.new(
  :message,
  :field_list)
  SENSITIVE = []
  include Aws::Structure
end