Class: Aws::DevOpsAgent::Types::ValidationExceptionField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Describes one specific validation failure for an input member.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

A detailed description of the validation failure.

Returns:

  • (String)


5295
5296
5297
5298
5299
5300
# File 'lib/aws-sdk-devopsagent/types.rb', line 5295

class ValidationExceptionField < Struct.new(
  :path,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

A JSONPointer expression to the structure member whose value failed to satisfy the modeled constraints.

Returns:

  • (String)


5295
5296
5297
5298
5299
5300
# File 'lib/aws-sdk-devopsagent/types.rb', line 5295

class ValidationExceptionField < Struct.new(
  :path,
  :message)
  SENSITIVE = []
  include Aws::Structure
end