Class: Aws::DevOpsAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DevOpsAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-devopsagent/client.rb
Overview
An API client for DevOpsAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DevOpsAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description.
-
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new asset in the specified agent space.
-
#create_asset_file(params = {}) ⇒ Types::CreateAssetFileResponse
Creates a file in an asset.
-
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space.
-
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space.
-
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
-
#create_trigger(params = {}) ⇒ Types::CreateTriggerResponse
Creates a new Trigger in the specified agent space.
-
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace.
-
#delete_asset(params = {}) ⇒ Struct
Deletes an asset and all its files from the specified agent space.
-
#delete_asset_file(params = {}) ⇒ Struct
Deletes a file from an asset.
-
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection.
-
#delete_trigger(params = {}) ⇒ Struct
Deletes a Trigger from the specified agent space.
-
#deregister_service(params = {}) ⇒ Struct
Deregister a service.
-
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
-
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace.
-
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace.
-
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace.
-
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
-
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
-
#get_asset(params = {}) ⇒ Types::GetAssetResponse
Gets an asset from the specified agent space.
-
#get_asset_content(params = {}) ⇒ Types::GetAssetContentResponse
Gets an asset’s content as a zip bundle.
-
#get_asset_file(params = {}) ⇒ Types::GetAssetFileResponse
Gets a file from an asset.
-
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
-
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id.
-
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow.
-
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID.
-
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it’s unique identifier.
-
#get_trigger(params = {}) ⇒ Types::GetTriggerResponse
Gets a Trigger from the specified agent space.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
-
#list_asset_files(params = {}) ⇒ Types::ListAssetFilesResponse
Lists files in an asset.
-
#list_asset_types(params = {}) ⇒ Types::ListAssetTypesResponse
Lists the supported asset types.
-
#list_asset_versions(params = {}) ⇒ Types::ListAssetVersionsResponse
Lists versions of an asset in the specified agent space.
-
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Lists assets in the specified agent space.
-
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace.
-
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting.
-
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user’s recent chat executions.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions.
-
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering.
-
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution.
-
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
-
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller’s account.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space.
-
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
-
#list_triggers(params = {}) ⇒ Types::ListTriggersResponse
Lists Triggers in the specified agent space.
-
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association.
-
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service.
-
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
-
#update_asset(params = {}) ⇒ Types::UpdateAssetResponse
Updates an asset in the specified agent space.
-
#update_asset_file(params = {}) ⇒ Types::UpdateAssetFileResponse
Updates a file in an asset.
-
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace.
-
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
-
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal.
-
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App.
-
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
-
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata.
-
#update_trigger(params = {}) ⇒ Types::UpdateTriggerResponse
Updates the status of an existing Trigger.
-
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
482 483 484 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 482 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4387 4388 4389 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4387 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4390 4391 4392 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4390 def errors_module Errors end |
Instance Method Details
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace. It overwrites the existing association of the same service. Returns 201 Created on success.
656 657 658 659 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 656 def associate_service(params = {}, = {}) req = build_request(:associate_service, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4360 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DevOpsAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-devopsagent' context[:gem_version] = '1.9.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description. Duplicate space names are allowed.
723 724 725 726 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 723 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new asset in the specified agent space
794 795 796 797 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 794 def create_asset(params = {}, = {}) req = build_request(:create_asset, params) req.send_request() end |
#create_asset_file(params = {}) ⇒ Types::CreateAssetFileResponse
Creates a file in an asset
860 861 862 863 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 860 def create_asset_file(params = {}, = {}) req = build_request(:create_asset_file, params) req.send_request() end |
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space
940 941 942 943 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 940 def create_backlog_task(params = {}, = {}) req = build_request(:create_backlog_task, params) req.send_request() end |
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space
981 982 983 984 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 981 def create_chat(params = {}, = {}) req = build_request(:create_chat, params) req.send_request() end |
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
1056 1057 1058 1059 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1056 def create_private_connection(params = {}, = {}) req = build_request(:create_private_connection, params) req.send_request() end |
#create_trigger(params = {}) ⇒ Types::CreateTriggerResponse
Creates a new Trigger in the specified agent space
1125 1126 1127 1128 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1125 def create_trigger(params = {}, = {}) req = build_request(:create_trigger, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
1148 1149 1150 1151 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1148 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_asset(params = {}) ⇒ Struct
Deletes an asset and all its files from the specified agent space
1174 1175 1176 1177 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1174 def delete_asset(params = {}, = {}) req = build_request(:delete_asset, params) req.send_request() end |
#delete_asset_file(params = {}) ⇒ Struct
Deletes a file from an asset
1204 1205 1206 1207 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1204 def delete_asset_file(params = {}, = {}) req = build_request(:delete_asset_file, params) req.send_request() end |
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection. The deletion is asynchronous and returns DELETE_IN_PROGRESS status.
1235 1236 1237 1238 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1235 def delete_private_connection(params = {}, = {}) req = build_request(:delete_private_connection, params) req.send_request() end |
#delete_trigger(params = {}) ⇒ Struct
Deletes a Trigger from the specified agent space
1263 1264 1265 1266 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1263 def delete_trigger(params = {}, = {}) req = build_request(:delete_trigger, params) req.send_request() end |
#deregister_service(params = {}) ⇒ Struct
Deregister a service
1286 1287 1288 1289 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1286 def deregister_service(params = {}, = {}) req = build_request(:deregister_service, params) req.send_request() end |
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
1335 1336 1337 1338 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1335 def describe_private_connection(params = {}, = {}) req = build_request(:describe_private_connection, params) req.send_request() end |
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace
1361 1362 1363 1364 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1361 def disable_operator_app(params = {}, = {}) req = build_request(:disable_operator_app, params) req.send_request() end |
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
1389 1390 1391 1392 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1389 def disassociate_service(params = {}, = {}) req = build_request(:disassociate_service, params) req.send_request() end |
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace
1465 1466 1467 1468 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1465 def enable_operator_app(params = {}, = {}) req = build_request(:enable_operator_app, params) req.send_request() end |
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
1499 1500 1501 1502 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1499 def get_account_usage(params = {}, = {}) req = build_request(:get_account_usage, params) req.send_request() end |
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
1536 1537 1538 1539 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1536 def get_agent_space(params = {}, = {}) req = build_request(:get_agent_space, params) req.send_request() end |
#get_asset(params = {}) ⇒ Types::GetAssetResponse
Gets an asset from the specified agent space
1577 1578 1579 1580 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1577 def get_asset(params = {}, = {}) req = build_request(:get_asset, params) req.send_request() end |
#get_asset_content(params = {}) ⇒ Types::GetAssetContentResponse
Gets an asset’s content as a zip bundle
1616 1617 1618 1619 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1616 def get_asset_content(params = {}, = {}) req = build_request(:get_asset_content, params) req.send_request() end |
#get_asset_file(params = {}) ⇒ Types::GetAssetFileResponse
Gets a file from an asset
1662 1663 1664 1665 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1662 def get_asset_file(params = {}, = {}) req = build_request(:get_asset_file, params) req.send_request() end |
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
1743 1744 1745 1746 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1743 def get_association(params = {}, = {}) req = build_request(:get_association, params) req.send_request() end |
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id
1793 1794 1795 1796 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1793 def get_backlog_task(params = {}, = {}) req = build_request(:get_backlog_task, params) req.send_request() end |
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow
1839 1840 1841 1842 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1839 def get_operator_app(params = {}, = {}) req = build_request(:get_operator_app, params) req.send_request() end |
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID
1892 1893 1894 1895 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1892 def get_recommendation(params = {}, = {}) req = build_request(:get_recommendation, params) req.send_request() end |
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it’s unique identifier
1974 1975 1976 1977 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1974 def get_service(params = {}, = {}) req = build_request(:get_service, params) req.send_request() end |
#get_trigger(params = {}) ⇒ Types::GetTriggerResponse
Gets a Trigger from the specified agent space
2014 2015 2016 2017 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2014 def get_trigger(params = {}, = {}) req = build_request(:get_trigger, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2057 2058 2059 2060 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2057 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_asset_files(params = {}) ⇒ Types::ListAssetFilesResponse
Lists files in an asset
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2111 2112 2113 2114 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2111 def list_asset_files(params = {}, = {}) req = build_request(:list_asset_files, params) req.send_request() end |
#list_asset_types(params = {}) ⇒ Types::ListAssetTypesResponse
Lists the supported asset types
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2150 2151 2152 2153 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2150 def list_asset_types(params = {}, = {}) req = build_request(:list_asset_types, params) req.send_request() end |
#list_asset_versions(params = {}) ⇒ Types::ListAssetVersionsResponse
Lists versions of an asset in the specified agent space
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2198 2199 2200 2201 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2198 def list_asset_versions(params = {}, = {}) req = build_request(:list_asset_versions, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Lists assets in the specified agent space
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2256 2257 2258 2259 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2256 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2351 2352 2353 2354 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2351 def list_associations(params = {}, = {}) req = build_request(:list_associations, params) req.send_request() end |
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2438 2439 2440 2441 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2438 def list_backlog_tasks(params = {}, = {}) req = build_request(:list_backlog_tasks, params) req.send_request() end |
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user’s recent chat executions
2487 2488 2489 2490 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2487 def list_chats(params = {}, = {}) req = build_request(:list_chats, params) req.send_request() end |
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2540 2541 2542 2543 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2540 def list_executions(params = {}, = {}) req = build_request(:list_executions, params) req.send_request() end |
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2603 2604 2605 2606 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2603 def list_goals(params = {}, = {}) req = build_request(:list_goals, params) req.send_request() end |
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2664 2665 2666 2667 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2664 def list_journal_records(params = {}, = {}) req = build_request(:list_journal_records, params) req.send_request() end |
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
2709 2710 2711 2712 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2709 def (params = {}, = {}) req = build_request(:list_pending_messages, params) req.send_request() end |
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller’s account.
2738 2739 2740 2741 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2738 def list_private_connections(params = {}, = {}) req = build_request(:list_private_connections, params) req.send_request() end |
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space
2809 2810 2811 2812 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2809 def list_recommendations(params = {}, = {}) req = build_request(:list_recommendations, params) req.send_request() end |
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2901 2902 2903 2904 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2901 def list_services(params = {}, = {}) req = build_request(:list_services, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
2930 2931 2932 2933 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2930 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_triggers(params = {}) ⇒ Types::ListTriggersResponse
Lists Triggers in the specified agent space
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2983 2984 2985 2986 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2983 def list_triggers(params = {}, = {}) req = build_request(:list_triggers, params) req.send_request() end |
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association
3018 3019 3020 3021 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3018 def list_webhooks(params = {}, = {}) req = build_request(:list_webhooks, params) req.send_request() end |
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service
3308 3309 3310 3311 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3308 def register_service(params = {}, = {}) req = build_request(:register_service, params) req.send_request() end |
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution
3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3572 def (params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::SendMessageEvents then handler when Proc then EventStreams::SendMessageEvents.new.tap(&handler) when nil then EventStreams::SendMessageEvents.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::DevOpsAgent::EventStreams::SendMessageEvents"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:send_message, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
3618 3619 3620 3621 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3618 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
3644 3645 3646 3647 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3644 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
3691 3692 3693 3694 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3691 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_asset(params = {}) ⇒ Types::UpdateAssetResponse
Updates an asset in the specified agent space
3763 3764 3765 3766 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3763 def update_asset(params = {}, = {}) req = build_request(:update_asset, params) req.send_request() end |
#update_asset_file(params = {}) ⇒ Types::UpdateAssetFileResponse
Updates a file in an asset
3830 3831 3832 3833 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3830 def update_asset_file(params = {}, = {}) req = build_request(:update_asset_file, params) req.send_request() end |
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace. Present fields are fully replaced; absent fields are left unchanged. Returns 200 OK on success.
4003 4004 4005 4006 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4003 def update_association(params = {}, = {}) req = build_request(:update_association, params) req.send_request() end |
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
4064 4065 4066 4067 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4064 def update_backlog_task(params = {}, = {}) req = build_request(:update_backlog_task, params) req.send_request() end |
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal
4123 4124 4125 4126 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4123 def update_goal(params = {}, = {}) req = build_request(:update_goal, params) req.send_request() end |
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App
4163 4164 4165 4166 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4163 def update_operator_app_idp_config(params = {}, = {}) req = build_request(:update_operator_app_idp_config, params) req.send_request() end |
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
4213 4214 4215 4216 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4213 def update_private_connection_certificate(params = {}, = {}) req = build_request(:update_private_connection_certificate, params) req.send_request() end |
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata
4277 4278 4279 4280 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4277 def update_recommendation(params = {}, = {}) req = build_request(:update_recommendation, params) req.send_request() end |
#update_trigger(params = {}) ⇒ Types::UpdateTriggerResponse
Updates the status of an existing Trigger
4328 4329 4330 4331 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4328 def update_trigger(params = {}, = {}) req = build_request(:update_trigger, params) req.send_request() end |
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
4351 4352 4353 4354 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4351 def validate_aws_associations(params = {}, = {}) req = build_request(:validate_aws_associations, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4380 4381 4382 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4380 def waiter_names [] end |