Class: Aws::DevOpsAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DevOpsAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-devopsagent/client.rb
Overview
An API client for DevOpsAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DevOpsAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description.
-
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new asset in the specified agent space.
-
#create_asset_file(params = {}) ⇒ Types::CreateAssetFileResponse
Creates a file in an asset.
-
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space.
-
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space.
-
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
-
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace.
-
#delete_asset(params = {}) ⇒ Struct
Deletes an asset and all its files from the specified agent space.
-
#delete_asset_file(params = {}) ⇒ Struct
Deletes a file from an asset.
-
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection.
-
#deregister_service(params = {}) ⇒ Struct
Deregister a service.
-
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
-
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace.
-
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace.
-
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace.
-
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
-
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
-
#get_asset(params = {}) ⇒ Types::GetAssetResponse
Gets an asset from the specified agent space.
-
#get_asset_content(params = {}) ⇒ Types::GetAssetContentResponse
Gets an asset’s content as a zip bundle.
-
#get_asset_file(params = {}) ⇒ Types::GetAssetFileResponse
Gets a file from an asset.
-
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
-
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id.
-
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow.
-
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID.
-
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it’s unique identifier.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
-
#list_asset_files(params = {}) ⇒ Types::ListAssetFilesResponse
Lists files in an asset.
-
#list_asset_types(params = {}) ⇒ Types::ListAssetTypesResponse
Lists the supported asset types.
-
#list_asset_versions(params = {}) ⇒ Types::ListAssetVersionsResponse
Lists versions of an asset in the specified agent space.
-
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Lists assets in the specified agent space.
-
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace.
-
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting.
-
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user’s recent chat executions.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions.
-
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering.
-
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution.
-
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
-
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller’s account.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space.
-
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
-
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association.
-
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service.
-
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
-
#update_asset(params = {}) ⇒ Types::UpdateAssetResponse
Updates an asset in the specified agent space.
-
#update_asset_file(params = {}) ⇒ Types::UpdateAssetFileResponse
Updates a file in an asset.
-
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace.
-
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
-
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal.
-
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App.
-
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
-
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata.
-
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
482 483 484 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 482 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4146 4147 4148 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4146 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4149 4150 4151 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4149 def errors_module Errors end |
Instance Method Details
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace. It overwrites the existing association of the same service. Returns 201 Created on success.
656 657 658 659 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 656 def associate_service(params = {}, = {}) req = build_request(:associate_service, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4119 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DevOpsAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-devopsagent' context[:gem_version] = '1.8.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description. Duplicate space names are allowed.
723 724 725 726 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 723 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new asset in the specified agent space
794 795 796 797 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 794 def create_asset(params = {}, = {}) req = build_request(:create_asset, params) req.send_request() end |
#create_asset_file(params = {}) ⇒ Types::CreateAssetFileResponse
Creates a file in an asset
860 861 862 863 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 860 def create_asset_file(params = {}, = {}) req = build_request(:create_asset_file, params) req.send_request() end |
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space
940 941 942 943 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 940 def create_backlog_task(params = {}, = {}) req = build_request(:create_backlog_task, params) req.send_request() end |
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space
981 982 983 984 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 981 def create_chat(params = {}, = {}) req = build_request(:create_chat, params) req.send_request() end |
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
1056 1057 1058 1059 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1056 def create_private_connection(params = {}, = {}) req = build_request(:create_private_connection, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
1079 1080 1081 1082 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1079 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_asset(params = {}) ⇒ Struct
Deletes an asset and all its files from the specified agent space
1105 1106 1107 1108 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1105 def delete_asset(params = {}, = {}) req = build_request(:delete_asset, params) req.send_request() end |
#delete_asset_file(params = {}) ⇒ Struct
Deletes a file from an asset
1135 1136 1137 1138 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1135 def delete_asset_file(params = {}, = {}) req = build_request(:delete_asset_file, params) req.send_request() end |
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection. The deletion is asynchronous and returns DELETE_IN_PROGRESS status.
1166 1167 1168 1169 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1166 def delete_private_connection(params = {}, = {}) req = build_request(:delete_private_connection, params) req.send_request() end |
#deregister_service(params = {}) ⇒ Struct
Deregister a service
1189 1190 1191 1192 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1189 def deregister_service(params = {}, = {}) req = build_request(:deregister_service, params) req.send_request() end |
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
1238 1239 1240 1241 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1238 def describe_private_connection(params = {}, = {}) req = build_request(:describe_private_connection, params) req.send_request() end |
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace
1264 1265 1266 1267 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1264 def disable_operator_app(params = {}, = {}) req = build_request(:disable_operator_app, params) req.send_request() end |
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
1292 1293 1294 1295 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1292 def disassociate_service(params = {}, = {}) req = build_request(:disassociate_service, params) req.send_request() end |
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace
1368 1369 1370 1371 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1368 def enable_operator_app(params = {}, = {}) req = build_request(:enable_operator_app, params) req.send_request() end |
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
1402 1403 1404 1405 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1402 def get_account_usage(params = {}, = {}) req = build_request(:get_account_usage, params) req.send_request() end |
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
1439 1440 1441 1442 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1439 def get_agent_space(params = {}, = {}) req = build_request(:get_agent_space, params) req.send_request() end |
#get_asset(params = {}) ⇒ Types::GetAssetResponse
Gets an asset from the specified agent space
1480 1481 1482 1483 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1480 def get_asset(params = {}, = {}) req = build_request(:get_asset, params) req.send_request() end |
#get_asset_content(params = {}) ⇒ Types::GetAssetContentResponse
Gets an asset’s content as a zip bundle
1519 1520 1521 1522 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1519 def get_asset_content(params = {}, = {}) req = build_request(:get_asset_content, params) req.send_request() end |
#get_asset_file(params = {}) ⇒ Types::GetAssetFileResponse
Gets a file from an asset
1565 1566 1567 1568 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1565 def get_asset_file(params = {}, = {}) req = build_request(:get_asset_file, params) req.send_request() end |
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
1646 1647 1648 1649 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1646 def get_association(params = {}, = {}) req = build_request(:get_association, params) req.send_request() end |
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id
1696 1697 1698 1699 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1696 def get_backlog_task(params = {}, = {}) req = build_request(:get_backlog_task, params) req.send_request() end |
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow
1742 1743 1744 1745 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1742 def get_operator_app(params = {}, = {}) req = build_request(:get_operator_app, params) req.send_request() end |
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID
1795 1796 1797 1798 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1795 def get_recommendation(params = {}, = {}) req = build_request(:get_recommendation, params) req.send_request() end |
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it’s unique identifier
1877 1878 1879 1880 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1877 def get_service(params = {}, = {}) req = build_request(:get_service, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1920 1921 1922 1923 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1920 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_asset_files(params = {}) ⇒ Types::ListAssetFilesResponse
Lists files in an asset
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1974 1975 1976 1977 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1974 def list_asset_files(params = {}, = {}) req = build_request(:list_asset_files, params) req.send_request() end |
#list_asset_types(params = {}) ⇒ Types::ListAssetTypesResponse
Lists the supported asset types
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2013 2014 2015 2016 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2013 def list_asset_types(params = {}, = {}) req = build_request(:list_asset_types, params) req.send_request() end |
#list_asset_versions(params = {}) ⇒ Types::ListAssetVersionsResponse
Lists versions of an asset in the specified agent space
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2061 2062 2063 2064 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2061 def list_asset_versions(params = {}, = {}) req = build_request(:list_asset_versions, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Lists assets in the specified agent space
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2119 2120 2121 2122 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2119 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2214 2215 2216 2217 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2214 def list_associations(params = {}, = {}) req = build_request(:list_associations, params) req.send_request() end |
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2301 2302 2303 2304 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2301 def list_backlog_tasks(params = {}, = {}) req = build_request(:list_backlog_tasks, params) req.send_request() end |
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user’s recent chat executions
2350 2351 2352 2353 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2350 def list_chats(params = {}, = {}) req = build_request(:list_chats, params) req.send_request() end |
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2403 2404 2405 2406 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2403 def list_executions(params = {}, = {}) req = build_request(:list_executions, params) req.send_request() end |
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2466 2467 2468 2469 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2466 def list_goals(params = {}, = {}) req = build_request(:list_goals, params) req.send_request() end |
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2527 2528 2529 2530 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2527 def list_journal_records(params = {}, = {}) req = build_request(:list_journal_records, params) req.send_request() end |
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
2572 2573 2574 2575 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2572 def (params = {}, = {}) req = build_request(:list_pending_messages, params) req.send_request() end |
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller’s account.
2601 2602 2603 2604 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2601 def list_private_connections(params = {}, = {}) req = build_request(:list_private_connections, params) req.send_request() end |
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space
2672 2673 2674 2675 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2672 def list_recommendations(params = {}, = {}) req = build_request(:list_recommendations, params) req.send_request() end |
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2764 2765 2766 2767 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2764 def list_services(params = {}, = {}) req = build_request(:list_services, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
2793 2794 2795 2796 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2793 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association
2828 2829 2830 2831 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2828 def list_webhooks(params = {}, = {}) req = build_request(:list_webhooks, params) req.send_request() end |
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service
3118 3119 3120 3121 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3118 def register_service(params = {}, = {}) req = build_request(:register_service, params) req.send_request() end |
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution
3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3382 def (params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::SendMessageEvents then handler when Proc then EventStreams::SendMessageEvents.new.tap(&handler) when nil then EventStreams::SendMessageEvents.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::DevOpsAgent::EventStreams::SendMessageEvents"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:send_message, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
3428 3429 3430 3431 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3428 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
3454 3455 3456 3457 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3454 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
3501 3502 3503 3504 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3501 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_asset(params = {}) ⇒ Types::UpdateAssetResponse
Updates an asset in the specified agent space
3573 3574 3575 3576 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3573 def update_asset(params = {}, = {}) req = build_request(:update_asset, params) req.send_request() end |
#update_asset_file(params = {}) ⇒ Types::UpdateAssetFileResponse
Updates a file in an asset
3640 3641 3642 3643 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3640 def update_asset_file(params = {}, = {}) req = build_request(:update_asset_file, params) req.send_request() end |
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace. Present fields are fully replaced; absent fields are left unchanged. Returns 200 OK on success.
3813 3814 3815 3816 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3813 def update_association(params = {}, = {}) req = build_request(:update_association, params) req.send_request() end |
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
3874 3875 3876 3877 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3874 def update_backlog_task(params = {}, = {}) req = build_request(:update_backlog_task, params) req.send_request() end |
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal
3933 3934 3935 3936 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3933 def update_goal(params = {}, = {}) req = build_request(:update_goal, params) req.send_request() end |
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App
3973 3974 3975 3976 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3973 def update_operator_app_idp_config(params = {}, = {}) req = build_request(:update_operator_app_idp_config, params) req.send_request() end |
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
4023 4024 4025 4026 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4023 def update_private_connection_certificate(params = {}, = {}) req = build_request(:update_private_connection_certificate, params) req.send_request() end |
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata
4087 4088 4089 4090 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4087 def update_recommendation(params = {}, = {}) req = build_request(:update_recommendation, params) req.send_request() end |
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
4110 4111 4112 4113 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4110 def validate_aws_associations(params = {}, = {}) req = build_request(:validate_aws_associations, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4139 4140 4141 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 4139 def waiter_names [] end |