Class: Aws::DevOpsAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DevOpsAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-devopsagent/client.rb
Overview
An API client for DevOpsAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DevOpsAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description.
-
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space.
-
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space.
-
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
-
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace.
-
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection.
-
#deregister_service(params = {}) ⇒ Struct
Deregister a service.
-
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
-
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace.
-
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace.
-
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace.
-
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
-
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
-
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
-
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id.
-
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow.
-
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID.
-
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it’s unique identifier.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
-
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace.
-
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting.
-
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user’s recent chat executions.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions.
-
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering.
-
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution.
-
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
-
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller’s account.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space.
-
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
-
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association.
-
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service.
-
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
-
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace.
-
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
-
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal.
-
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App.
-
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
-
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata.
-
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
482 483 484 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 482 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3452 3453 3454 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3452 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3455 3456 3457 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3455 def errors_module Errors end |
Instance Method Details
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace. It overwrites the existing association of the same service. Returns 201 Created on success.
656 657 658 659 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 656 def associate_service(params = {}, = {}) req = build_request(:associate_service, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3425 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DevOpsAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-devopsagent' context[:gem_version] = '1.6.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description. Duplicate space names are allowed.
723 724 725 726 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 723 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space
803 804 805 806 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 803 def create_backlog_task(params = {}, = {}) req = build_request(:create_backlog_task, params) req.send_request() end |
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space
844 845 846 847 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 844 def create_chat(params = {}, = {}) req = build_request(:create_chat, params) req.send_request() end |
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
914 915 916 917 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 914 def create_private_connection(params = {}, = {}) req = build_request(:create_private_connection, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
937 938 939 940 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 937 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection. The deletion is asynchronous and returns DELETE_IN_PROGRESS status.
968 969 970 971 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 968 def delete_private_connection(params = {}, = {}) req = build_request(:delete_private_connection, params) req.send_request() end |
#deregister_service(params = {}) ⇒ Struct
Deregister a service
991 992 993 994 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 991 def deregister_service(params = {}, = {}) req = build_request(:deregister_service, params) req.send_request() end |
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1036 def describe_private_connection(params = {}, = {}) req = build_request(:describe_private_connection, params) req.send_request() end |
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace
1062 1063 1064 1065 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1062 def disable_operator_app(params = {}, = {}) req = build_request(:disable_operator_app, params) req.send_request() end |
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
1090 1091 1092 1093 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1090 def disassociate_service(params = {}, = {}) req = build_request(:disassociate_service, params) req.send_request() end |
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace
1164 1165 1166 1167 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1164 def enable_operator_app(params = {}, = {}) req = build_request(:enable_operator_app, params) req.send_request() end |
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
1198 1199 1200 1201 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1198 def get_account_usage(params = {}, = {}) req = build_request(:get_account_usage, params) req.send_request() end |
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
1235 1236 1237 1238 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1235 def get_agent_space(params = {}, = {}) req = build_request(:get_agent_space, params) req.send_request() end |
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
1316 1317 1318 1319 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1316 def get_association(params = {}, = {}) req = build_request(:get_association, params) req.send_request() end |
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id
1366 1367 1368 1369 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1366 def get_backlog_task(params = {}, = {}) req = build_request(:get_backlog_task, params) req.send_request() end |
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow
1410 1411 1412 1413 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1410 def get_operator_app(params = {}, = {}) req = build_request(:get_operator_app, params) req.send_request() end |
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID
1463 1464 1465 1466 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1463 def get_recommendation(params = {}, = {}) req = build_request(:get_recommendation, params) req.send_request() end |
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it’s unique identifier
1544 1545 1546 1547 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1544 def get_service(params = {}, = {}) req = build_request(:get_service, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1587 1588 1589 1590 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1587 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1682 1683 1684 1685 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1682 def list_associations(params = {}, = {}) req = build_request(:list_associations, params) req.send_request() end |
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1769 1770 1771 1772 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1769 def list_backlog_tasks(params = {}, = {}) req = build_request(:list_backlog_tasks, params) req.send_request() end |
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user’s recent chat executions
1818 1819 1820 1821 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1818 def list_chats(params = {}, = {}) req = build_request(:list_chats, params) req.send_request() end |
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1871 1872 1873 1874 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1871 def list_executions(params = {}, = {}) req = build_request(:list_executions, params) req.send_request() end |
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1934 1935 1936 1937 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1934 def list_goals(params = {}, = {}) req = build_request(:list_goals, params) req.send_request() end |
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1995 1996 1997 1998 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1995 def list_journal_records(params = {}, = {}) req = build_request(:list_journal_records, params) req.send_request() end |
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
2040 2041 2042 2043 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2040 def (params = {}, = {}) req = build_request(:list_pending_messages, params) req.send_request() end |
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller’s account.
2067 2068 2069 2070 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2067 def list_private_connections(params = {}, = {}) req = build_request(:list_private_connections, params) req.send_request() end |
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space
2138 2139 2140 2141 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2138 def list_recommendations(params = {}, = {}) req = build_request(:list_recommendations, params) req.send_request() end |
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2229 2230 2231 2232 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2229 def list_services(params = {}, = {}) req = build_request(:list_services, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
2258 2259 2260 2261 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2258 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association
2293 2294 2295 2296 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2293 def list_webhooks(params = {}, = {}) req = build_request(:list_webhooks, params) req.send_request() end |
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service
2571 2572 2573 2574 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2571 def register_service(params = {}, = {}) req = build_request(:register_service, params) req.send_request() end |
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution
2831 2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2831 def (params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::SendMessageEvents then handler when Proc then EventStreams::SendMessageEvents.new.tap(&handler) when nil then EventStreams::SendMessageEvents.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::DevOpsAgent::EventStreams::SendMessageEvents"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:send_message, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
2877 2878 2879 2880 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2877 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
2903 2904 2905 2906 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2903 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
2950 2951 2952 2953 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2950 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace. Present fields are fully replaced; absent fields are left unchanged. Returns 200 OK on success.
3123 3124 3125 3126 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3123 def update_association(params = {}, = {}) req = build_request(:update_association, params) req.send_request() end |
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
3184 3185 3186 3187 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3184 def update_backlog_task(params = {}, = {}) req = build_request(:update_backlog_task, params) req.send_request() end |
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal
3243 3244 3245 3246 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3243 def update_goal(params = {}, = {}) req = build_request(:update_goal, params) req.send_request() end |
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App
3283 3284 3285 3286 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3283 def update_operator_app_idp_config(params = {}, = {}) req = build_request(:update_operator_app_idp_config, params) req.send_request() end |
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
3329 3330 3331 3332 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3329 def update_private_connection_certificate(params = {}, = {}) req = build_request(:update_private_connection_certificate, params) req.send_request() end |
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata
3393 3394 3395 3396 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3393 def update_recommendation(params = {}, = {}) req = build_request(:update_recommendation, params) req.send_request() end |
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
3416 3417 3418 3419 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3416 def validate_aws_associations(params = {}, = {}) req = build_request(:validate_aws_associations, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3445 3446 3447 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3445 def waiter_names [] end |