Class: Aws::DevOpsAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DevOpsAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-devopsagent/client.rb
Overview
An API client for DevOpsAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DevOpsAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description.
-
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space.
-
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space.
-
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
-
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace.
-
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection.
-
#deregister_service(params = {}) ⇒ Struct
Deregister a service.
-
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
-
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace.
-
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace.
-
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace.
-
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
-
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
-
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
-
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id.
-
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow.
-
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID.
-
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it’s unique identifier.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
-
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace.
-
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting.
-
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user’s recent chat executions.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions.
-
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering.
-
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution.
-
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
-
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller’s account.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space.
-
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
-
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association.
-
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service.
-
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
-
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace.
-
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
-
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal.
-
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App.
-
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
-
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata.
-
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
484 485 486 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 484 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3413 3414 3415 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3413 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3416 3417 3418 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3416 def errors_module Errors end |
Instance Method Details
#associate_service(params = {}) ⇒ Types::AssociateServiceOutput
Adds a specific service association to an AgentSpace. It overwrites the existing association of the same service. Returns 201 Created on success.
653 654 655 656 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 653 def associate_service(params = {}, = {}) req = build_request(:associate_service, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3386 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DevOpsAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-devopsagent' context[:gem_version] = '1.3.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new AgentSpace with the specified name and description. Duplicate space names are allowed.
720 721 722 723 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 720 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_backlog_task(params = {}) ⇒ Types::CreateBacklogTaskResponse
Creates a new backlog task in the specified agent space
800 801 802 803 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 800 def create_backlog_task(params = {}, = {}) req = build_request(:create_backlog_task, params) req.send_request() end |
#create_chat(params = {}) ⇒ Types::CreateChatResponse
Creates a new chat execution in the specified agent space
841 842 843 844 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 841 def create_chat(params = {}, = {}) req = build_request(:create_chat, params) req.send_request() end |
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a Private Connection to a target resource.
911 912 913 914 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 911 def create_private_connection(params = {}, = {}) req = build_request(:create_private_connection, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Struct
Deletes an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
934 935 936 937 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 934 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a Private Connection. The deletion is asynchronous and returns DELETE_IN_PROGRESS status.
965 966 967 968 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 965 def delete_private_connection(params = {}, = {}) req = build_request(:delete_private_connection, params) req.send_request() end |
#deregister_service(params = {}) ⇒ Struct
Deregister a service
988 989 990 991 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 988 def deregister_service(params = {}, = {}) req = build_request(:deregister_service, params) req.send_request() end |
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves details of an existing Private Connection.
1033 1034 1035 1036 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1033 def describe_private_connection(params = {}, = {}) req = build_request(:describe_private_connection, params) req.send_request() end |
#disable_operator_app(params = {}) ⇒ Struct
Disable the Operator App for the specified AgentSpace
1059 1060 1061 1062 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1059 def disable_operator_app(params = {}, = {}) req = build_request(:disable_operator_app, params) req.send_request() end |
#disassociate_service(params = {}) ⇒ Struct
Deletes a specific service association from an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
1087 1088 1089 1090 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1087 def disassociate_service(params = {}, = {}) req = build_request(:disassociate_service, params) req.send_request() end |
#enable_operator_app(params = {}) ⇒ Types::EnableOperatorAppOutput
Enable the Operator App to access the given AgentSpace
1161 1162 1163 1164 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1161 def enable_operator_app(params = {}, = {}) req = build_request(:enable_operator_app, params) req.send_request() end |
#get_account_usage(params = {}) ⇒ Types::GetAccountUsageOutput
Retrieves monthly account usage metrics and limits for the AWS account.
1195 1196 1197 1198 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1195 def get_account_usage(params = {}, = {}) req = build_request(:get_account_usage, params) req.send_request() end |
#get_agent_space(params = {}) ⇒ Types::GetAgentSpaceOutput
Retrieves detailed information about a specific AgentSpace.
1232 1233 1234 1235 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1232 def get_agent_space(params = {}, = {}) req = build_request(:get_agent_space, params) req.send_request() end |
#get_association(params = {}) ⇒ Types::GetAssociationOutput
Retrieves given associations configured for a specific AgentSpace.
1311 1312 1313 1314 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1311 def get_association(params = {}, = {}) req = build_request(:get_association, params) req.send_request() end |
#get_backlog_task(params = {}) ⇒ Types::GetBacklogTaskResponse
Gets a backlog task for the specified agent space and task id
1361 1362 1363 1364 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1361 def get_backlog_task(params = {}, = {}) req = build_request(:get_backlog_task, params) req.send_request() end |
#get_operator_app(params = {}) ⇒ Types::GetOperatorAppOutput
Get the full auth configuration of operator including any enabled auth flow
1405 1406 1407 1408 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1405 def get_operator_app(params = {}, = {}) req = build_request(:get_operator_app, params) req.send_request() end |
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves a specific recommendation by its ID
1456 1457 1458 1459 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1456 def get_recommendation(params = {}, = {}) req = build_request(:get_recommendation, params) req.send_request() end |
#get_service(params = {}) ⇒ Types::GetServiceOutput
Retrieves given service by it’s unique identifier
1529 1530 1531 1532 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1529 def get_service(params = {}, = {}) req = build_request(:get_service, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Lists all AgentSpaces with optional pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1572 1573 1574 1575 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1572 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_associations(params = {}) ⇒ Types::ListAssociationsOutput
List all associations for given AgentSpace
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1665 1666 1667 1668 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1665 def list_associations(params = {}, = {}) req = build_request(:list_associations, params) req.send_request() end |
#list_backlog_tasks(params = {}) ⇒ Types::ListBacklogTasksResponse
Lists backlog tasks in the specified agent space with optional filtering and sorting
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1760 1761 1762 1763 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1760 def list_backlog_tasks(params = {}, = {}) req = build_request(:list_backlog_tasks, params) req.send_request() end |
#list_chats(params = {}) ⇒ Types::ListChatsResponse
Retrieves a paginated list of the user’s recent chat executions
1809 1810 1811 1812 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1809 def list_chats(params = {}, = {}) req = build_request(:list_chats, params) req.send_request() end |
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
List executions
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1862 1863 1864 1865 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1862 def list_executions(params = {}, = {}) req = build_request(:list_executions, params) req.send_request() end |
#list_goals(params = {}) ⇒ Types::ListGoalsResponse
Lists goals in the specified agent space with optional filtering
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1925 1926 1927 1928 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1925 def list_goals(params = {}, = {}) req = build_request(:list_goals, params) req.send_request() end |
#list_journal_records(params = {}) ⇒ Types::ListJournalRecordsResponse
List journal records for a specific execution
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1986 1987 1988 1989 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 1986 def list_journal_records(params = {}, = {}) req = build_request(:list_journal_records, params) req.send_request() end |
#list_pending_messages(params = {}) ⇒ Types::ListPendingMessagesResponse
List pending messages for a specific execution.
2031 2032 2033 2034 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2031 def (params = {}, = {}) req = build_request(:list_pending_messages, params) req.send_request() end |
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists all Private Connections in the caller’s account.
2058 2059 2060 2061 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2058 def list_private_connections(params = {}, = {}) req = build_request(:list_private_connections, params) req.send_request() end |
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists recommendations for the specified agent space
2127 2128 2129 2130 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2127 def list_recommendations(params = {}, = {}) req = build_request(:list_recommendations, params) req.send_request() end |
#list_services(params = {}) ⇒ Types::ListServicesOutput
List a list of registered service on the account level.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2210 2211 2212 2213 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2210 def list_services(params = {}, = {}) req = build_request(:list_services, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified AWS DevOps Agent resource.
2239 2240 2241 2242 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2239 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
List all webhooks for given Association
2274 2275 2276 2277 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2274 def list_webhooks(params = {}, = {}) req = build_request(:list_webhooks, params) req.send_request() end |
#register_service(params = {}) ⇒ Types::RegisterServiceOutput
This operation registers the specified service
2539 2540 2541 2542 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2539 def register_service(params = {}, = {}) req = build_request(:register_service, params) req.send_request() end |
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a chat message and streams the response for the specified agent space execution
2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2799 def (params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::SendMessageEvents then handler when Proc then EventStreams::SendMessageEvents.new.tap(&handler) when nil then EventStreams::SendMessageEvents.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::DevOpsAgent::EventStreams::SendMessageEvents"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:send_message, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites tags for the specified AWS DevOps Agent resource.
2845 2846 2847 2848 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2845 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified AWS DevOps Agent resource.
2871 2872 2873 2874 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2871 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the information of an existing AgentSpace.
2918 2919 2920 2921 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 2918 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_association(params = {}) ⇒ Types::UpdateAssociationOutput
Partially updates the configuration of an existing service association for an AgentSpace. Present fields are fully replaced; absent fields are left unchanged. Returns 200 OK on success.
3086 3087 3088 3089 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3086 def update_association(params = {}, = {}) req = build_request(:update_association, params) req.send_request() end |
#update_backlog_task(params = {}) ⇒ Types::UpdateBacklogTaskResponse
Update an existing backlog task.
3147 3148 3149 3150 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3147 def update_backlog_task(params = {}, = {}) req = build_request(:update_backlog_task, params) req.send_request() end |
#update_goal(params = {}) ⇒ Types::UpdateGoalResponse
Update an existing goal
3206 3207 3208 3209 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3206 def update_goal(params = {}, = {}) req = build_request(:update_goal, params) req.send_request() end |
#update_operator_app_idp_config(params = {}) ⇒ Types::UpdateOperatorAppIdpConfigOutput
Update the external Identity Provider configuration for the Operator App
3246 3247 3248 3249 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3246 def update_operator_app_idp_config(params = {}, = {}) req = build_request(:update_operator_app_idp_config, params) req.send_request() end |
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a Private Connection.
3292 3293 3294 3295 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3292 def update_private_connection_certificate(params = {}, = {}) req = build_request(:update_private_connection_certificate, params) req.send_request() end |
#update_recommendation(params = {}) ⇒ Types::UpdateRecommendationResponse
Updates an existing recommendation with new content, status, or metadata
3354 3355 3356 3357 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3354 def update_recommendation(params = {}, = {}) req = build_request(:update_recommendation, params) req.send_request() end |
#validate_aws_associations(params = {}) ⇒ Struct
Validates an aws association and set status and returns a 204 No Content response on success.
3377 3378 3379 3380 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3377 def validate_aws_associations(params = {}, = {}) req = build_request(:validate_aws_associations, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3406 3407 3408 |
# File 'lib/aws-sdk-devopsagent/client.rb', line 3406 def waiter_names [] end |