Class: Aws::DevOpsAgent::Types::AssetFileBody
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::AssetFileBody
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
AssetFileBody is a union - when making an API calls you must set exactly one of the members.
Note:
AssetFileBody is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AssetFileBody corresponding to the set member.
Content of an individual asset file
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
Binary file content.
-
#text ⇒ String
Text file content.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
Binary file content
337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 337 class AssetFileBody < Struct.new( :bytes, :text, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < AssetFileBody; end class Text < AssetFileBody; end class Unknown < AssetFileBody; end end |
#text ⇒ String
Text file content
337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 337 class AssetFileBody < Struct.new( :bytes, :text, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < AssetFileBody; end class Text < AssetFileBody; end class Unknown < AssetFileBody; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
337 338 339 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 337 def unknown @unknown end |