Class: Aws::DevOpsAgent::Types::AssistantMessageBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::AssistantMessageBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
AssistantMessageBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AssistantMessageBlock corresponding to the set member.
A block of content in an assistant message.
Defined Under Namespace
Classes: Text, ToolUse, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
Text content from the assistant.
-
#tool_use ⇒ Hash, ...
Tool use request from the assistant.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ String
Text content from the assistant.
222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 222 class AssistantMessageBlock < Struct.new( :text, :tool_use, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < AssistantMessageBlock; end class ToolUse < AssistantMessageBlock; end class Unknown < AssistantMessageBlock; end end |
#tool_use ⇒ Hash, ...
Tool use request from the assistant.
222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 222 class AssistantMessageBlock < Struct.new( :text, :tool_use, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < AssistantMessageBlock; end class ToolUse < AssistantMessageBlock; end class Unknown < AssistantMessageBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
222 223 224 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 222 def unknown @unknown end |