Class: Aws::DevOpsAgent::Types::CreateAssetFileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::CreateAssetFileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for creating an asset file
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset to create the file in.
-
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset file creation.
-
#content ⇒ Types::AssetFileBody
The content of the file to create.
-
#metadata ⇒ Hash, ...
Optional metadata describing this file.
-
#path ⇒ String
The path of the file within the asset.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
779 780 781 782 783 784 785 786 787 788 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 779 class CreateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset to create the file in
779 780 781 782 783 784 785 786 787 788 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 779 class CreateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset file creation
**A suitable default value is auto-generated.** You should normally not need to pass this option.
779 780 781 782 783 784 785 786 787 788 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 779 class CreateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::AssetFileBody
The content of the file to create
779 780 781 782 783 784 785 786 787 788 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 779 class CreateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash, ...
Optional metadata describing this file
779 780 781 782 783 784 785 786 787 788 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 779 class CreateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path of the file within the asset
779 780 781 782 783 784 785 786 787 788 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 779 class CreateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |