Class: Aws::DevOpsAgent::Types::CreateAssetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for creating a new asset

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space where the asset will be created

Returns:

  • (String)


833
834
835
836
837
838
839
840
841
# File 'lib/aws-sdk-devopsagent/types.rb', line 833

class CreateAssetRequest < Struct.new(
  :agent_space_id,
  :asset_type,
  :metadata,
  :content,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#asset_typeString

The type of asset to create

Returns:

  • (String)


833
834
835
836
837
838
839
840
841
# File 'lib/aws-sdk-devopsagent/types.rb', line 833

class CreateAssetRequest < Struct.new(
  :agent_space_id,
  :asset_type,
  :metadata,
  :content,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier used for idempotent asset creation

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


833
834
835
836
837
838
839
840
841
# File 'lib/aws-sdk-devopsagent/types.rb', line 833

class CreateAssetRequest < Struct.new(
  :agent_space_id,
  :asset_type,
  :metadata,
  :content,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contentTypes::AssetContent

The content for the asset. Provide a single file or a zip bundle.

Returns:



833
834
835
836
837
838
839
840
841
# File 'lib/aws-sdk-devopsagent/types.rb', line 833

class CreateAssetRequest < Struct.new(
  :agent_space_id,
  :asset_type,
  :metadata,
  :content,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash, ...

The metadata describing this asset

Returns:

  • (Hash, Array, String, Numeric, Boolean)


833
834
835
836
837
838
839
840
841
# File 'lib/aws-sdk-devopsagent/types.rb', line 833

class CreateAssetRequest < Struct.new(
  :agent_space_id,
  :asset_type,
  :metadata,
  :content,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end