Class: Aws::DevOpsAgent::Types::CreateAssetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::CreateAssetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for creating a new asset
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space where the asset will be created.
-
#asset_type ⇒ String
The type of asset to create.
-
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset creation.
-
#content ⇒ Types::AssetContent
The content for the asset.
-
#metadata ⇒ Hash, ...
The metadata describing this asset.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space where the asset will be created
833 834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 833 class CreateAssetRequest < Struct.new( :agent_space_id, :asset_type, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#asset_type ⇒ String
The type of asset to create
833 834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 833 class CreateAssetRequest < Struct.new( :agent_space_id, :asset_type, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset creation
**A suitable default value is auto-generated.** You should normally not need to pass this option.
833 834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 833 class CreateAssetRequest < Struct.new( :agent_space_id, :asset_type, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::AssetContent
The content for the asset. Provide a single file or a zip bundle.
833 834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 833 class CreateAssetRequest < Struct.new( :agent_space_id, :asset_type, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash, ...
The metadata describing this asset
833 834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 833 class CreateAssetRequest < Struct.new( :agent_space_id, :asset_type, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |