Class: Aws::DevOpsAgent::Types::CreateBacklogTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::CreateBacklogTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for creating a new backlog task
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space where the task will be created.
-
#client_token ⇒ String
Client-provided token for idempotent operations.
-
#description ⇒ String
Optional detailed description of the task.
-
#priority ⇒ String
The priority level of the task.
-
#reference ⇒ Types::ReferenceInput
Optional reference information for the task.
-
#task_type ⇒ String
The type of task being created.
-
#title ⇒ String
The title of the backlog task.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space where the task will be created
524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 524 class CreateBacklogTaskRequest < Struct.new( :agent_space_id, :reference, :task_type, :title, :description, :priority, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Client-provided token for idempotent operations
**A suitable default value is auto-generated.** You should normally not need to pass this option.
524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 524 class CreateBacklogTaskRequest < Struct.new( :agent_space_id, :reference, :task_type, :title, :description, :priority, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Optional detailed description of the task
524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 524 class CreateBacklogTaskRequest < Struct.new( :agent_space_id, :reference, :task_type, :title, :description, :priority, :client_token) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
The priority level of the task
524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 524 class CreateBacklogTaskRequest < Struct.new( :agent_space_id, :reference, :task_type, :title, :description, :priority, :client_token) SENSITIVE = [] include Aws::Structure end |
#reference ⇒ Types::ReferenceInput
Optional reference information for the task
524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 524 class CreateBacklogTaskRequest < Struct.new( :agent_space_id, :reference, :task_type, :title, :description, :priority, :client_token) SENSITIVE = [] include Aws::Structure end |
#task_type ⇒ String
The type of task being created
524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 524 class CreateBacklogTaskRequest < Struct.new( :agent_space_id, :reference, :task_type, :title, :description, :priority, :client_token) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the backlog task
524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 524 class CreateBacklogTaskRequest < Struct.new( :agent_space_id, :reference, :task_type, :title, :description, :priority, :client_token) SENSITIVE = [] include Aws::Structure end |