Class: Aws::DevOpsAgent::Types::CreateChatRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for creating a new chat

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)

Returns:

  • (String)


569
570
571
572
573
574
575
# File 'lib/aws-sdk-devopsagent/types.rb', line 569

class CreateChatRequest < Struct.new(
  :agent_space_id,
  :user_id,
  :user_type)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The user identifier for the chat. This field is deprecated and will be ignored — the service resolves user identity from the authenticated session.

Returns:

  • (String)


569
570
571
572
573
574
575
# File 'lib/aws-sdk-devopsagent/types.rb', line 569

class CreateChatRequest < Struct.new(
  :agent_space_id,
  :user_id,
  :user_type)
  SENSITIVE = []
  include Aws::Structure
end

#user_typeString

The authentication type of the user

Returns:

  • (String)


569
570
571
572
573
574
575
# File 'lib/aws-sdk-devopsagent/types.rb', line 569

class CreateChatRequest < Struct.new(
  :agent_space_id,
  :user_id,
  :user_type)
  SENSITIVE = []
  include Aws::Structure
end