Class: Aws::DevOpsAgent::Types::CreateChatRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::CreateChatRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for creating a new chat
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters).
-
#user_id ⇒ String
The user identifier for the chat.
-
#user_type ⇒ String
The authentication type of the user.
Instance Attribute Details
#agent_space_id ⇒ String
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
569 570 571 572 573 574 575 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 569 class CreateChatRequest < Struct.new( :agent_space_id, :user_id, :user_type) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The user identifier for the chat. This field is deprecated and will be ignored — the service resolves user identity from the authenticated session.
569 570 571 572 573 574 575 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 569 class CreateChatRequest < Struct.new( :agent_space_id, :user_id, :user_type) SENSITIVE = [] include Aws::Structure end |
#user_type ⇒ String
The authentication type of the user
569 570 571 572 573 574 575 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 569 class CreateChatRequest < Struct.new( :agent_space_id, :user_id, :user_type) SENSITIVE = [] include Aws::Structure end |