Class: Aws::DevOpsAgent::Types::CreatePrivateConnectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Input for creating a new Private Connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#modeTypes::PrivateConnectionMode

Private Connection mode configuration.



618
619
620
621
622
623
624
# File 'lib/aws-sdk-devopsagent/types.rb', line 618

class CreatePrivateConnectionInput < Struct.new(
  :name,
  :mode,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Unique name for this Private Connection within the account.

Returns:

  • (String)


618
619
620
621
622
623
624
# File 'lib/aws-sdk-devopsagent/types.rb', line 618

class CreatePrivateConnectionInput < Struct.new(
  :name,
  :mode,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Tags to add to the Private Connection at creation time.

Returns:

  • (Hash<String,String>)


618
619
620
621
622
623
624
# File 'lib/aws-sdk-devopsagent/types.rb', line 618

class CreatePrivateConnectionInput < Struct.new(
  :name,
  :mode,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end