Class: Aws::DevOpsAgent::Types::CreatePrivateConnectionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::CreatePrivateConnectionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Input for creating a new Private Connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mode ⇒ Types::PrivateConnectionMode
Private Connection mode configuration.
-
#name ⇒ String
Unique name for this Private Connection within the account.
-
#tags ⇒ Hash<String,String>
Tags to add to the Private Connection at creation time.
Instance Attribute Details
#mode ⇒ Types::PrivateConnectionMode
Private Connection mode configuration.
612 613 614 615 616 617 618 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 612 class CreatePrivateConnectionInput < Struct.new( :name, :mode, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Unique name for this Private Connection within the account.
612 613 614 615 616 617 618 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 612 class CreatePrivateConnectionInput < Struct.new( :name, :mode, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags to add to the Private Connection at creation time.
612 613 614 615 616 617 618 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 612 class CreatePrivateConnectionInput < Struct.new( :name, :mode, :tags) SENSITIVE = [] include Aws::Structure end |