Class: Aws::DevOpsAgent::Types::CreateTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::CreateTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for creating a new Trigger
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ Hash, ...
The action the new Trigger performs when it fires.
-
#agent_space_id ⇒ String
The unique identifier for the agent space where the Trigger will be created.
-
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent Trigger creation.
-
#condition ⇒ Types::TriggerCondition
The condition that fires the new Trigger.
-
#status ⇒ String
The initial status of the Trigger.
-
#type ⇒ String
How the new Trigger fires.
Instance Attribute Details
#action ⇒ Hash, ...
The action the new Trigger performs when it fires
1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150 class CreateTriggerRequest < Struct.new( :agent_space_id, :type, :condition, :action, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#agent_space_id ⇒ String
The unique identifier for the agent space where the Trigger will be created
1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150 class CreateTriggerRequest < Struct.new( :agent_space_id, :type, :condition, :action, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent Trigger creation
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150 class CreateTriggerRequest < Struct.new( :agent_space_id, :type, :condition, :action, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#condition ⇒ Types::TriggerCondition
The condition that fires the new Trigger
1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150 class CreateTriggerRequest < Struct.new( :agent_space_id, :type, :condition, :action, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The initial status of the Trigger
1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150 class CreateTriggerRequest < Struct.new( :agent_space_id, :type, :condition, :action, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
How the new Trigger fires
1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1150 class CreateTriggerRequest < Struct.new( :agent_space_id, :type, :condition, :action, :status, :client_token) SENSITIVE = [] include Aws::Structure end |