Class: Aws::DevOpsAgent::Types::CreateTriggerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionHash, ...

The action the new Trigger performs when it fires

Returns:

  • (Hash, Array, String, Numeric, Boolean)


1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
# File 'lib/aws-sdk-devopsagent/types.rb', line 1090

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#agent_space_idString

Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)

Returns:

  • (String)


1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
# File 'lib/aws-sdk-devopsagent/types.rb', line 1090

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier used for idempotent Trigger creation

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
# File 'lib/aws-sdk-devopsagent/types.rb', line 1090

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#conditionTypes::TriggerCondition

The condition that fires the new Trigger



1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
# File 'lib/aws-sdk-devopsagent/types.rb', line 1090

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The initial status of the Trigger

Returns:

  • (String)


1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
# File 'lib/aws-sdk-devopsagent/types.rb', line 1090

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

How the new Trigger fires

Returns:

  • (String)


1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
# File 'lib/aws-sdk-devopsagent/types.rb', line 1090

class CreateTriggerRequest < Struct.new(
  :agent_space_id,
  :type,
  :condition,
  :action,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end