Class: Aws::DevOpsAgent::Types::DeleteAssetFileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for deleting an asset file

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space containing the asset

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-devopsagent/types.rb', line 1147

class DeleteAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#asset_idString

The unique identifier of the asset containing the file

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-devopsagent/types.rb', line 1147

class DeleteAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path of the file within the asset to delete

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-devopsagent/types.rb', line 1147

class DeleteAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path)
  SENSITIVE = []
  include Aws::Structure
end