Class: Aws::DevOpsAgent::Types::GetAssetFileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetAssetFileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for getting an asset file
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset containing the file.
-
#asset_version ⇒ Integer
The specific asset version to retrieve the file from.
-
#path ⇒ String
The path of the file within the asset to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1798 class GetAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :asset_version) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset containing the file
1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1798 class GetAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :asset_version) SENSITIVE = [] include Aws::Structure end |
#asset_version ⇒ Integer
The specific asset version to retrieve the file from. If omitted, the latest version is returned.
1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1798 class GetAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :asset_version) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path of the file within the asset to retrieve
1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1798 class GetAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :asset_version) SENSITIVE = [] include Aws::Structure end |