Class: Aws::DevOpsAgent::Types::GetBacklogTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::GetBacklogTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for retrieving a specific backlog task
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the task.
-
#task_id ⇒ String
The unique identifier of the task to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the task
1328 1329 1330 1331 1332 1333 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1328 class GetBacklogTaskRequest < Struct.new( :agent_space_id, :task_id) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task to retrieve
1328 1329 1330 1331 1332 1333 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1328 class GetBacklogTaskRequest < Struct.new( :agent_space_id, :task_id) SENSITIVE = [] include Aws::Structure end |