Class: Aws::DevOpsAgent::Types::Goal

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Represents a goal with all its properties and metadata

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_arnString

The unique identifier for the agent space containing this goal

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#contentTypes::GoalContent

Content of the goal

Returns:



1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

Timestamp when this goal was created

Returns:

  • (Time)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_scheduleTypes::GoalSchedule

Goal Schedule. Allows to schedule the goal to run periodically, as well as disable a goal temporarily

Returns:



1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#goal_idString

The unique identifier for this goal

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#goal_typeString

Type of goal based on its origin

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#last_evaluated_atTime

Timestamp when the goal was last evaluated

Returns:

  • (Time)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#last_successful_task_idString

ID of the most recent successful task associated with this goal

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#last_task_idString

ID of the most recent task associated with this goal

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Current status of the goal itself

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the goal

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

Timestamp when this goal was last updated

Returns:

  • (Time)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

Version number for optimistic locking

Returns:

  • (Integer)


1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612

class Goal < Struct.new(
  :agent_space_arn,
  :goal_id,
  :title,
  :content,
  :status,
  :goal_type,
  :created_at,
  :updated_at,
  :last_evaluated_at,
  :last_task_id,
  :last_successful_task_id,
  :version,
  :evaluation_schedule)
  SENSITIVE = []
  include Aws::Structure
end