Class: Aws::DevOpsAgent::Types::Goal
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::Goal
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Represents a goal with all its properties and metadata
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_arn ⇒ String
The unique identifier for the agent space containing this goal.
-
#content ⇒ Types::GoalContent
Content of the goal.
-
#created_at ⇒ Time
Timestamp when this goal was created.
-
#evaluation_schedule ⇒ Types::GoalSchedule
Goal Schedule.
-
#goal_id ⇒ String
The unique identifier for this goal.
-
#goal_type ⇒ String
Type of goal based on its origin.
-
#last_evaluated_at ⇒ Time
Timestamp when the goal was last evaluated.
-
#last_successful_task_id ⇒ String
ID of the most recent successful task associated with this goal.
-
#last_task_id ⇒ String
ID of the most recent task associated with this goal.
-
#status ⇒ String
Current status of the goal itself.
-
#title ⇒ String
The title of the goal.
-
#updated_at ⇒ Time
Timestamp when this goal was last updated.
-
#version ⇒ Integer
Version number for optimistic locking.
Instance Attribute Details
#agent_space_arn ⇒ String
The unique identifier for the agent space containing this goal
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::GoalContent
Content of the goal
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp when this goal was created
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#evaluation_schedule ⇒ Types::GoalSchedule
Goal Schedule. Allows to schedule the goal to run periodically, as well as disable a goal temporarily
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#goal_id ⇒ String
The unique identifier for this goal
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#goal_type ⇒ String
Type of goal based on its origin
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#last_evaluated_at ⇒ Time
Timestamp when the goal was last evaluated
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#last_successful_task_id ⇒ String
ID of the most recent successful task associated with this goal
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#last_task_id ⇒ String
ID of the most recent task associated with this goal
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Current status of the goal itself
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the goal
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp when this goal was last updated
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
Version number for optimistic locking
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 1612 class Goal < Struct.new( :agent_space_arn, :goal_id, :title, :content, :status, :goal_type, :created_at, :updated_at, :last_evaluated_at, :last_task_id, :last_successful_task_id, :version, :evaluation_schedule) SENSITIVE = [] include Aws::Structure end |