Class: Aws::DevOpsAgent::Types::ListBacklogTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ListBacklogTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for listing backlog tasks with filtering, sorting, and pagination support
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the tasks.
-
#filter ⇒ Types::TaskFilter
Filter criteria to apply when listing tasks Filtering restrictions: - Each filter field list is limited to a single value - Filtering by Priority and Status at the same time when not filtering by Type is not permitted - Timestamp filters (createdAfter, createdBefore) can be combined with other filters when not sorting by priority.
-
#limit ⇒ Integer
Maximum number of tasks to return in a single response (1-1000, default: 100).
-
#next_token ⇒ String
Token for retrieving the next page of results.
-
#order ⇒ String
Sort order for the tasks based on sortField (default: DESC).
-
#sort_field ⇒ String
Field to sort by Sorting restrictions: - Only sorting on createdAt is supported when using priority or status filters alone.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the tasks
3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3119 class ListBacklogTasksRequest < Struct.new( :agent_space_id, :filter, :limit, :next_token, :sort_field, :order) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::TaskFilter
Filter criteria to apply when listing tasks Filtering restrictions:
- Each filter field list is limited to a single value - Filtering by Priority and Status at the same time when not filtering by Type is not permitted - Timestamp filters (createdAfter, createdBefore) can be combined with other filters when not sorting by priority
3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3119 class ListBacklogTasksRequest < Struct.new( :agent_space_id, :filter, :limit, :next_token, :sort_field, :order) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
Maximum number of tasks to return in a single response (1-1000, default: 100)
3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3119 class ListBacklogTasksRequest < Struct.new( :agent_space_id, :filter, :limit, :next_token, :sort_field, :order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for retrieving the next page of results
3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3119 class ListBacklogTasksRequest < Struct.new( :agent_space_id, :filter, :limit, :next_token, :sort_field, :order) SENSITIVE = [] include Aws::Structure end |
#order ⇒ String
Sort order for the tasks based on sortField (default: DESC)
3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3119 class ListBacklogTasksRequest < Struct.new( :agent_space_id, :filter, :limit, :next_token, :sort_field, :order) SENSITIVE = [] include Aws::Structure end |
#sort_field ⇒ String
Field to sort by Sorting restrictions: - Only sorting on createdAt is supported when using priority or status filters alone. - Sorting by priority is not supported when using Timestamp filters (createdAfter, createdBefore)
3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3119 class ListBacklogTasksRequest < Struct.new( :agent_space_id, :filter, :limit, :next_token, :sort_field, :order) SENSITIVE = [] include Aws::Structure end |