Class: Aws::DevOpsAgent::Types::ListPendingMessagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ListPendingMessagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for listing pending messages with filtering and pagination support
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters).
-
#execution_id ⇒ String
The unique identifier of the execution whose journal records to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
3378 3379 3380 3381 3382 3383 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3378 class ListPendingMessagesRequest < Struct.new( :agent_space_id, :execution_id) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The unique identifier of the execution whose journal records to retrieve
3378 3379 3380 3381 3382 3383 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3378 class ListPendingMessagesRequest < Struct.new( :agent_space_id, :execution_id) SENSITIVE = [] include Aws::Structure end |