Class: Aws::DevOpsAgent::Types::ListRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ListRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for listing recommendations with filtering and pagination support
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the recommendations.
-
#goal_id ⇒ String
Optional goal ID to filter recommendations by specific goal.
-
#limit ⇒ Integer
Maximum number of recommendations to return in a single response.
-
#next_token ⇒ String
Token for retrieving the next page of results.
-
#priority ⇒ String
Optional priority to filter recommendations by priority level.
-
#status ⇒ String
Optional status to filter recommendations by their current status.
-
#task_id ⇒ String
Optional task ID to filter recommendations by specific task.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the recommendations
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471 class ListRecommendationsRequest < Struct.new( :agent_space_id, :task_id, :goal_id, :status, :priority, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#goal_id ⇒ String
Optional goal ID to filter recommendations by specific goal
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471 class ListRecommendationsRequest < Struct.new( :agent_space_id, :task_id, :goal_id, :status, :priority, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
Maximum number of recommendations to return in a single response
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471 class ListRecommendationsRequest < Struct.new( :agent_space_id, :task_id, :goal_id, :status, :priority, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for retrieving the next page of results
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471 class ListRecommendationsRequest < Struct.new( :agent_space_id, :task_id, :goal_id, :status, :priority, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
Optional priority to filter recommendations by priority level
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471 class ListRecommendationsRequest < Struct.new( :agent_space_id, :task_id, :goal_id, :status, :priority, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Optional status to filter recommendations by their current status
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471 class ListRecommendationsRequest < Struct.new( :agent_space_id, :task_id, :goal_id, :status, :priority, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
Optional task ID to filter recommendations by specific task
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3471 class ListRecommendationsRequest < Struct.new( :agent_space_id, :task_id, :goal_id, :status, :priority, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |