Class: Aws::DevOpsAgent::Types::ListServicesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ListServicesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Output containing a list of registered services and pagination token.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
Token to retrieve the next page of results, if there are more results.
-
#services ⇒ Array<Types::RegisteredService>
List of registered services.
Instance Attribute Details
#next_token ⇒ String
Token to retrieve the next page of results, if there are more results.
3541 3542 3543 3544 3545 3546 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3541 class ListServicesOutput < Struct.new( :next_token, :services) SENSITIVE = [] include Aws::Structure end |
#services ⇒ Array<Types::RegisteredService>
List of registered services.
3541 3542 3543 3544 3545 3546 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3541 class ListServicesOutput < Struct.new( :next_token, :services) SENSITIVE = [] include Aws::Structure end |