Class: Aws::DevOpsAgent::Types::Recommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::Recommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Represents a recommendation with all its properties and metadata
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_context ⇒ String
Additional context for recommendation.
-
#agent_space_arn ⇒ String
ARN of the agent space this recommendation belongs to.
-
#content ⇒ Types::RecommendationContent
Content of the recommendation.
-
#created_at ⇒ Time
Timestamp when this recommendation was created.
-
#goal_id ⇒ String
ID of the goal this recommendation is associated with.
-
#goal_version ⇒ Integer
Version of the goal at the time this recommendation was generated.
-
#priority ⇒ String
Priority level of the recommendation.
-
#rank_position ⇒ Integer
Position in ranked list (1 = highest priority).
-
#ranked_at ⇒ Time
Timestamp when the recommendation was last ranked.
-
#recommendation_id ⇒ String
The unique identifier for this recommendation.
-
#status ⇒ String
Current status of the recommendation.
-
#task_id ⇒ String
ID of the task that generated the recommendation.
-
#title ⇒ String
The title of the recommendation.
-
#updated_at ⇒ Time
Timestamp when this recommendation was last updated.
-
#version ⇒ Integer
Version number for optimistic locking.
Instance Attribute Details
#additional_context ⇒ String
Additional context for recommendation
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#agent_space_arn ⇒ String
ARN of the agent space this recommendation belongs to
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::RecommendationContent
Content of the recommendation
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp when this recommendation was created
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#goal_id ⇒ String
ID of the goal this recommendation is associated with
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#goal_version ⇒ Integer
Version of the goal at the time this recommendation was generated
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
Priority level of the recommendation
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#rank_position ⇒ Integer
Position in ranked list (1 = highest priority)
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#ranked_at ⇒ Time
Timestamp when the recommendation was last ranked
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#recommendation_id ⇒ String
The unique identifier for this recommendation
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Current status of the recommendation
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
ID of the task that generated the recommendation
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the recommendation
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp when this recommendation was last updated
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
Version number for optimistic locking
4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4078 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |