Class: Aws::DevOpsAgent::Types::Recommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::Recommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Represents a recommendation with all its properties and metadata
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_context ⇒ String
Additional context for recommendation.
-
#agent_space_arn ⇒ String
ARN of the agent space this recommendation belongs to.
-
#content ⇒ Types::RecommendationContent
Content of the recommendation.
-
#created_at ⇒ Time
Timestamp when this recommendation was created.
-
#goal_id ⇒ String
ID of the goal this recommendation is associated with.
-
#goal_version ⇒ Integer
Version of the goal at the time this recommendation was generated.
-
#priority ⇒ String
Priority level of the recommendation.
-
#rank_position ⇒ Integer
Position in ranked list (1 = highest priority).
-
#ranked_at ⇒ Time
Timestamp when the recommendation was last ranked.
-
#recommendation_id ⇒ String
The unique identifier for this recommendation.
-
#status ⇒ String
Current status of the recommendation.
-
#task_id ⇒ String
ID of the task that generated the recommendation.
-
#title ⇒ String
The title of the recommendation.
-
#updated_at ⇒ Time
Timestamp when this recommendation was last updated.
-
#version ⇒ Integer
Version number for optimistic locking.
Instance Attribute Details
#additional_context ⇒ String
Additional context for recommendation
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#agent_space_arn ⇒ String
ARN of the agent space this recommendation belongs to
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::RecommendationContent
Content of the recommendation
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp when this recommendation was created
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#goal_id ⇒ String
ID of the goal this recommendation is associated with
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#goal_version ⇒ Integer
Version of the goal at the time this recommendation was generated
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
Priority level of the recommendation
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#rank_position ⇒ Integer
Position in ranked list (1 = highest priority)
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#ranked_at ⇒ Time
Timestamp when the recommendation was last ranked
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#recommendation_id ⇒ String
The unique identifier for this recommendation
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Current status of the recommendation
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
ID of the task that generated the recommendation
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the recommendation
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp when this recommendation was last updated
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
Version number for optimistic locking
3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3276 class Recommendation < Struct.new( :agent_space_arn, :recommendation_id, :task_id, :goal_id, :title, :content, :status, :priority, :goal_version, :additional_context, :rank_position, :ranked_at, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |