Class: Aws::DevOpsAgent::Types::ReferenceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ReferenceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Reference information linking a task to external systems - for input with validation
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
Association identifier of the external system.
-
#reference_id ⇒ String
The unique identifier in the external system.
-
#reference_url ⇒ String
URL to access the reference in the external system.
-
#system ⇒ String
The name of the external system.
-
#title ⇒ String
Optional title for the reference.
Instance Attribute Details
#association_id ⇒ String
Association identifier of the external system
3258 3259 3260 3261 3262 3263 3264 3265 3266 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3258 class ReferenceInput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |
#reference_id ⇒ String
The unique identifier in the external system
3258 3259 3260 3261 3262 3263 3264 3265 3266 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3258 class ReferenceInput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |
#reference_url ⇒ String
URL to access the reference in the external system
3258 3259 3260 3261 3262 3263 3264 3265 3266 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3258 class ReferenceInput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |
#system ⇒ String
The name of the external system
3258 3259 3260 3261 3262 3263 3264 3265 3266 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3258 class ReferenceInput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
Optional title for the reference
3258 3259 3260 3261 3262 3263 3264 3265 3266 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3258 class ReferenceInput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |