Class: Aws::DevOpsAgent::Types::ReferenceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ReferenceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Reference information linking a task to external systems - for output without validation
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
Association identifier of the external system.
-
#reference_id ⇒ String
The unique identifier in the external system.
-
#reference_url ⇒ String
URL to access the reference in the external system.
-
#system ⇒ String
The name of the external system.
-
#title ⇒ String
Optional title for the reference.
Instance Attribute Details
#association_id ⇒ String
Association identifier of the external system
3293 3294 3295 3296 3297 3298 3299 3300 3301 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293 class ReferenceOutput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |
#reference_id ⇒ String
The unique identifier in the external system
3293 3294 3295 3296 3297 3298 3299 3300 3301 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293 class ReferenceOutput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |
#reference_url ⇒ String
URL to access the reference in the external system
3293 3294 3295 3296 3297 3298 3299 3300 3301 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293 class ReferenceOutput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |
#system ⇒ String
The name of the external system
3293 3294 3295 3296 3297 3298 3299 3300 3301 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293 class ReferenceOutput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
Optional title for the reference
3293 3294 3295 3296 3297 3298 3299 3300 3301 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3293 class ReferenceOutput < Struct.new( :system, :title, :reference_id, :reference_url, :association_id) SENSITIVE = [] include Aws::Structure end |