Class: Aws::DevOpsAgent::Types::SendMessageContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::SendMessageContext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Context object for additional message metadata
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_page ⇒ String
The current page or view the user is on.
-
#last_message ⇒ String
The ID of the last message in the conversation.
-
#user_action_response ⇒ String
Response to a UI prompt (not a text conversation message).
Instance Attribute Details
#current_page ⇒ String
The current page or view the user is on
3816 3817 3818 3819 3820 3821 3822 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3816 class SendMessageContext < Struct.new( :current_page, :last_message, :user_action_response) SENSITIVE = [] include Aws::Structure end |
#last_message ⇒ String
The ID of the last message in the conversation
3816 3817 3818 3819 3820 3821 3822 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3816 class SendMessageContext < Struct.new( :current_page, :last_message, :user_action_response) SENSITIVE = [] include Aws::Structure end |
#user_action_response ⇒ String
Response to a UI prompt (not a text conversation message)
3816 3817 3818 3819 3820 3821 3822 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 3816 class SendMessageContext < Struct.new( :current_page, :last_message, :user_action_response) SENSITIVE = [] include Aws::Structure end |