Class: Aws::DevOpsAgent::Types::ServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Note:

ServiceConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

ServiceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ServiceConfiguration corresponding to the set member.

Union of all supported service configuration types. Each service has its own specific configuration structure.

Defined Under Namespace

Classes: Aws, Azure, Azuredevops, Dynatrace, EventChannel, Github, Gitlab, Mcpserver, Mcpserverdatadog, Mcpservergrafana, Mcpservernewrelic, Mcpserversigv4, Mcpserversplunk, Pagerduty, Servicenow, Slack, SourceAws, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#awsTypes::AWSConfiguration

AWS monitor account configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#azureTypes::AzureConfiguration

Azure subscription integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#azuredevopsTypes::AzureDevOpsConfiguration

Azure DevOps project integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#dynatraceTypes::DynatraceConfiguration

Dynatrace monitoring integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#event_channelTypes::EventChannelConfiguration

Event Channel instance integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#githubTypes::GitHubConfiguration

GitHub repository integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#gitlabTypes::GitLabConfiguration

GitLab project integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserverTypes::MCPServerConfiguration

MCP (Model Context Protocol) server integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserverdatadogTypes::MCPServerDatadogConfiguration

Datadog MCP server integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpservergrafanaTypes::MCPServerGrafanaConfiguration

Grafana MCP server integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpservernewrelicTypes::MCPServerNewRelicConfiguration

NewRelic instance integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserversigv4Types::MCPServerSigV4Configuration

SigV4-authenticated MCP server integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserversplunkTypes::MCPServerSplunkConfiguration

Splunk MCP server integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#pagerdutyTypes::PagerDutyConfiguration

PagerDuty integration configuration



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#servicenowTypes::ServiceNowConfiguration

ServiceNow instance integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#slackTypes::SlackConfiguration

Slack workspace integration configuration.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#source_awsTypes::SourceAwsConfiguration

AWS source account configuration for monitoring resources.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5247
5248
5249
# File 'lib/aws-sdk-devopsagent/types.rb', line 5247

def unknown
  @unknown
end