Class: Aws::DevOpsAgent::Types::ServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Note:

ServiceConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

ServiceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ServiceConfiguration corresponding to the set member.

Union of all supported service configuration types. Each service has its own specific configuration structure.

Defined Under Namespace

Classes: Aws, Azure, Azuredevops, Dynatrace, EventChannel, Github, Gitlab, Mcpserver, Mcpserverdatadog, Mcpservergrafana, Mcpservernewrelic, Mcpserversigv4, Mcpserversplunk, Pagerduty, Servicenow, Slack, SourceAws, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#awsTypes::AWSConfiguration

AWS monitor account configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#azureTypes::AzureConfiguration

Azure subscription integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#azuredevopsTypes::AzureDevOpsConfiguration

Azure DevOps project integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#dynatraceTypes::DynatraceConfiguration

Dynatrace monitoring integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#event_channelTypes::EventChannelConfiguration

Event Channel instance integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#githubTypes::GitHubConfiguration

GitHub repository integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#gitlabTypes::GitLabConfiguration

GitLab project integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserverTypes::MCPServerConfiguration

MCP (Model Context Protocol) server integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserverdatadogTypes::MCPServerDatadogConfiguration

Datadog MCP server integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpservergrafanaTypes::MCPServerGrafanaConfiguration

Grafana MCP server integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpservernewrelicTypes::MCPServerNewRelicConfiguration

NewRelic instance integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserversigv4Types::MCPServerSigV4Configuration

SigV4-authenticated MCP server integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserversplunkTypes::MCPServerSplunkConfiguration

Splunk MCP server integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#pagerdutyTypes::PagerDutyConfiguration

PagerDuty integration configuration



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#servicenowTypes::ServiceNowConfiguration

ServiceNow instance integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#slackTypes::SlackConfiguration

Slack workspace integration configuration.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#source_awsTypes::SourceAwsConfiguration

AWS source account configuration for monitoring resources.



5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5079
5080
5081
# File 'lib/aws-sdk-devopsagent/types.rb', line 5079

def unknown
  @unknown
end