Class: Aws::DevOpsAgent::Types::ServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Note:

ServiceConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

ServiceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ServiceConfiguration corresponding to the set member.

Union of all supported service configuration types. Each service has its own specific configuration structure.

Defined Under Namespace

Classes: Aws, Azure, Azuredevops, Dynatrace, EventChannel, Github, Gitlab, Mcpserver, Mcpserverdatadog, Mcpservergrafana, Mcpservernewrelic, Mcpserversigv4, Mcpserversplunk, Pagerduty, Servicenow, Slack, SourceAws, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#awsTypes::AWSConfiguration

AWS monitor account configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#azureTypes::AzureConfiguration

Azure subscription integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#azuredevopsTypes::AzureDevOpsConfiguration

Azure DevOps project integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#dynatraceTypes::DynatraceConfiguration

Dynatrace monitoring integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#event_channelTypes::EventChannelConfiguration

Event Channel instance integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#githubTypes::GitHubConfiguration

GitHub repository integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#gitlabTypes::GitLabConfiguration

GitLab project integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserverTypes::MCPServerConfiguration

MCP (Model Context Protocol) server integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserverdatadogTypes::MCPServerDatadogConfiguration

Datadog MCP server integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpservergrafanaTypes::MCPServerGrafanaConfiguration

Grafana MCP server integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpservernewrelicTypes::MCPServerNewRelicConfiguration

NewRelic instance integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserversigv4Types::MCPServerSigV4Configuration

SigV4-authenticated MCP server integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#mcpserversplunkTypes::MCPServerSplunkConfiguration

Splunk MCP server integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#pagerdutyTypes::PagerDutyConfiguration

PagerDuty integration configuration



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#servicenowTypes::ServiceNowConfiguration

ServiceNow instance integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#slackTypes::SlackConfiguration

Slack workspace integration configuration.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#source_awsTypes::SourceAwsConfiguration

AWS source account configuration for monitoring resources.



4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

class ServiceConfiguration < Struct.new(
  :source_aws,
  :aws,
  :github,
  :slack,
  :dynatrace,
  :servicenow,
  :mcpservernewrelic,
  :mcpserverdatadog,
  :mcpserver,
  :gitlab,
  :mcpserversplunk,
  :event_channel,
  :azure,
  :azuredevops,
  :mcpservergrafana,
  :pagerduty,
  :mcpserversigv4,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SourceAws < ServiceConfiguration; end
  class Aws < ServiceConfiguration; end
  class Github < ServiceConfiguration; end
  class Slack < ServiceConfiguration; end
  class Dynatrace < ServiceConfiguration; end
  class Servicenow < ServiceConfiguration; end
  class Mcpservernewrelic < ServiceConfiguration; end
  class Mcpserverdatadog < ServiceConfiguration; end
  class Mcpserver < ServiceConfiguration; end
  class Gitlab < ServiceConfiguration; end
  class Mcpserversplunk < ServiceConfiguration; end
  class EventChannel < ServiceConfiguration; end
  class Azure < ServiceConfiguration; end
  class Azuredevops < ServiceConfiguration; end
  class Mcpservergrafana < ServiceConfiguration; end
  class Pagerduty < ServiceConfiguration; end
  class Mcpserversigv4 < ServiceConfiguration; end
  class Unknown < ServiceConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4254
4255
4256
# File 'lib/aws-sdk-devopsagent/types.rb', line 4254

def unknown
  @unknown
end