Class: Aws::DevOpsAgent::Types::ServiceManagedInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Configuration for a service-managed Private Connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificateString

Certificate for the Private Connection.

Returns:

  • (String)


4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-devopsagent/types.rb', line 4285

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate)
  SENSITIVE = []
  include Aws::Structure
end

#host_addressString

IP address or DNS name of the target resource.

Returns:

  • (String)


4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-devopsagent/types.rb', line 4285

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

IP address type of the service-managed Resource Gateway.

Returns:

  • (String)


4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-devopsagent/types.rb', line 4285

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate)
  SENSITIVE = []
  include Aws::Structure
end

#ipv4_addresses_per_eniInteger

Number of IPv4 addresses in each ENI for the service-managed Resource Gateway.

Returns:

  • (Integer)


4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-devopsagent/types.rb', line 4285

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate)
  SENSITIVE = []
  include Aws::Structure
end

#port_rangesArray<String>

TCP port ranges that a consumer can use to access the resource.

Returns:

  • (Array<String>)


4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-devopsagent/types.rb', line 4285

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

Security groups to attach to the service-managed Resource Gateway. If not specified, a default security group is created.

Returns:

  • (Array<String>)


4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-devopsagent/types.rb', line 4285

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

Subnets that the service-managed Resource Gateway will span.

Returns:

  • (Array<String>)


4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-devopsagent/types.rb', line 4285

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

VPC to create the service-managed Resource Gateway in.

Returns:

  • (String)


4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-devopsagent/types.rb', line 4285

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate)
  SENSITIVE = []
  include Aws::Structure
end