Class: Aws::DevOpsAgent::Types::SlackBidirectionalConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::SlackBidirectionalConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Configuration for bidirectional Slack communication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Whether bidirectional communication is enabled for this association.
-
#role_arn ⇒ String
IAM role ARN that AWS DevOps Agent assumes to exchange messages with your Slack workspace on behalf of this association.
Instance Attribute Details
#enabled ⇒ Boolean
Whether bidirectional communication is enabled for this association. When you set this value to true, you can mention the agent in a configured Slack channel and it responds in that channel. When you omit this value or set it to false, the agent ignores mentions and only sends notifications.
6166 6167 6168 6169 6170 6171 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6166 class SlackBidirectionalConfiguration < Struct.new( :role_arn, :enabled) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
IAM role ARN that AWS DevOps Agent assumes to exchange messages with your Slack workspace on behalf of this association.
6166 6167 6168 6169 6170 6171 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6166 class SlackBidirectionalConfiguration < Struct.new( :role_arn, :enabled) SENSITIVE = [] include Aws::Structure end |