Class: Aws::DevOpsAgent::Types::Task
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::Task
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Represents a backlog task with all its properties and metadata
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing this task.
-
#created_at ⇒ Time
Timestamp when this task was created.
-
#description ⇒ String
Optional detailed description of the task.
-
#execution_id ⇒ String
The execution ID associated with this task, if any.
-
#has_linked_tasks ⇒ Boolean
Indicates if this task has other tasks linked to it.
-
#metadata ⇒ Hash, ...
Optional metadata for the task.
-
#primary_task_id ⇒ String
The task ID of the primary investigation this task is linked to.
-
#priority ⇒ String
The priority level of this task.
-
#reference ⇒ Types::ReferenceOutput
Optional reference information linking this task to external systems.
-
#status ⇒ String
The current status of this task.
-
#status_reason ⇒ String
Explanation for why the task status was changed (e.g., linked reason).
-
#support_metadata ⇒ Hash, ...
Optional support metadata for the task.
-
#task_id ⇒ String
The unique identifier for this task.
-
#task_type ⇒ String
The type of this task.
-
#title ⇒ String
The title of the task.
-
#updated_at ⇒ Time
Timestamp when this task was last updated.
-
#version ⇒ Integer
Version number for optimistic locking.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing this task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp when this task was created
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Optional detailed description of the task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The execution ID associated with this task, if any
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#has_linked_tasks ⇒ Boolean
Indicates if this task has other tasks linked to it
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash, ...
Optional metadata for the task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#primary_task_id ⇒ String
The task ID of the primary investigation this task is linked to
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
The priority level of this task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#reference ⇒ Types::ReferenceOutput
Optional reference information linking this task to external systems
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of this task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Explanation for why the task status was changed (e.g., linked reason)
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#support_metadata ⇒ Hash, ...
Optional support metadata for the task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier for this task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#task_type ⇒ String
The type of this task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the task
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp when this task was last updated
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
Version number for optimistic locking
6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6392 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |