Class: Aws::DevOpsAgent::Types::Task

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Represents a backlog task with all its properties and metadata

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space containing this task

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

Timestamp when this task was created

Returns:

  • (Time)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Optional detailed description of the task

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#execution_idString

The execution ID associated with this task, if any

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#has_linked_tasksBoolean

Indicates if this task has other tasks linked to it

Returns:

  • (Boolean)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash, ...

Optional metadata for the task

Returns:

  • (Hash, Array, String, Numeric, Boolean)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#primary_task_idString

The task ID of the primary investigation this task is linked to

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#priorityString

The priority level of this task

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#referenceTypes::ReferenceOutput

Optional reference information linking this task to external systems



6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of this task

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Explanation for why the task status was changed (e.g., linked reason)

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#support_metadataHash, ...

Optional support metadata for the task

Returns:

  • (Hash, Array, String, Numeric, Boolean)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier for this task

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#task_typeString

The type of this task

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the task

Returns:

  • (String)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

Timestamp when this task was last updated

Returns:

  • (Time)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

Version number for optimistic locking

Returns:

  • (Integer)


6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-devopsagent/types.rb', line 6361

class Task < Struct.new(
  :agent_space_id,
  :task_id,
  :execution_id,
  :title,
  :description,
  :reference,
  :task_type,
  :priority,
  :status,
  :created_at,
  :updated_at,
  :version,
  :support_metadata,
  :metadata,
  :primary_task_id,
  :status_reason,
  :has_linked_tasks)
  SENSITIVE = []
  include Aws::Structure
end