Class: Aws::DevOpsAgent::Types::Task
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::Task
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Represents a backlog task with all its properties and metadata
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing this task.
-
#created_at ⇒ Time
Timestamp when this task was created.
-
#description ⇒ String
Optional detailed description of the task.
-
#execution_id ⇒ String
The execution ID associated with this task, if any.
-
#has_linked_tasks ⇒ Boolean
Indicates if this task has other tasks linked to it.
-
#metadata ⇒ Hash, ...
Optional metadata for the task.
-
#primary_task_id ⇒ String
The task ID of the primary investigation this task is linked to.
-
#priority ⇒ String
The priority level of this task.
-
#reference ⇒ Types::ReferenceOutput
Optional reference information linking this task to external systems.
-
#status ⇒ String
The current status of this task.
-
#status_reason ⇒ String
Explanation for why the task status was changed (e.g., linked reason).
-
#support_metadata ⇒ Hash, ...
Optional support metadata for the task.
-
#task_id ⇒ String
The unique identifier for this task.
-
#task_type ⇒ String
The type of this task.
-
#title ⇒ String
The title of the task.
-
#updated_at ⇒ Time
Timestamp when this task was last updated.
-
#version ⇒ Integer
Version number for optimistic locking.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing this task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp when this task was created
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Optional detailed description of the task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The execution ID associated with this task, if any
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#has_linked_tasks ⇒ Boolean
Indicates if this task has other tasks linked to it
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash, ...
Optional metadata for the task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#primary_task_id ⇒ String
The task ID of the primary investigation this task is linked to
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
The priority level of this task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#reference ⇒ Types::ReferenceOutput
Optional reference information linking this task to external systems
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of this task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Explanation for why the task status was changed (e.g., linked reason)
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#support_metadata ⇒ Hash, ...
Optional support metadata for the task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier for this task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#task_type ⇒ String
The type of this task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the task
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp when this task was last updated
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
Version number for optimistic locking
5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5558 class Task < Struct.new( :agent_space_id, :task_id, :execution_id, :title, :description, :reference, :task_type, :priority, :status, :created_at, :updated_at, :version, :support_metadata, :metadata, :primary_task_id, :status_reason, :has_linked_tasks) SENSITIVE = [] include Aws::Structure end |