Class: Aws::DevOpsAgent::Types::TriggerCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::TriggerCondition
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
TriggerCondition is a union - when making an API calls you must set exactly one of the members.
Note:
TriggerCondition is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TriggerCondition corresponding to the set member.
Defines the firing condition for a Trigger
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#schedule ⇒ Types::ScheduleCondition
Time-based firing condition.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#schedule ⇒ Types::ScheduleCondition
Time-based firing condition
6499 6500 6501 6502 6503 6504 6505 6506 6507 6508 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6499 class TriggerCondition < Struct.new( :schedule, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Schedule < TriggerCondition; end class Unknown < TriggerCondition; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6499 6500 6501 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6499 def unknown @unknown end |