Class: Aws::DevOpsAgent::Types::TriggerCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::TriggerCondition
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
TriggerCondition is a union - when making an API calls you must set exactly one of the members.
Note:
TriggerCondition is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TriggerCondition corresponding to the set member.
Defines the firing condition for a Trigger
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#schedule ⇒ Types::ScheduleCondition
Time-based firing condition.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#schedule ⇒ Types::ScheduleCondition
Time-based firing condition
5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5866 class TriggerCondition < Struct.new( :schedule, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Schedule < TriggerCondition; end class Unknown < TriggerCondition; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5866 5867 5868 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5866 def unknown @unknown end |