Class: Aws::DevOpsAgent::Types::UpdateAgentSpaceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateAgentSpaceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Input for updating an existing AgentSpace's properties. All fields except agentSpaceId are optional for partial updates.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the AgentSpace.
-
#description ⇒ String
The updated description of the AgentSpace.
-
#locale ⇒ String
The updated locale for the AgentSpace, which determines the language used in agent responses.
-
#name ⇒ String
The updated name of the AgentSpace.
-
#preferences ⇒ Hash<String,Boolean>
The preferences to configure on the agent space.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the AgentSpace
6582 6583 6584 6585 6586 6587 6588 6589 6590 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6582 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The updated description of the AgentSpace.
6582 6583 6584 6585 6586 6587 6588 6589 6590 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6582 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#locale ⇒ String
The updated locale for the AgentSpace, which determines the language used in agent responses.
6582 6583 6584 6585 6586 6587 6588 6589 6590 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6582 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The updated name of the AgentSpace.
6582 6583 6584 6585 6586 6587 6588 6589 6590 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6582 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale, :preferences) SENSITIVE = [:description] include Aws::Structure end |
#preferences ⇒ Hash<String,Boolean>
The preferences to configure on the agent space. When provided, this replaces the full set of configured preferences; preferences not included revert to their default values. When omitted, the current preferences are left unchanged.
6582 6583 6584 6585 6586 6587 6588 6589 6590 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6582 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale, :preferences) SENSITIVE = [:description] include Aws::Structure end |