Class: Aws::DevOpsAgent::Types::UpdateAgentSpaceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateAgentSpaceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Input for updating an existing AgentSpace’s properties. All fields except agentSpaceId are optional for partial updates.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the AgentSpace.
-
#description ⇒ String
The updated description of the AgentSpace.
-
#locale ⇒ String
The updated locale for the AgentSpace, which determines the language used in agent responses.
-
#name ⇒ String
The updated name of the AgentSpace.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the AgentSpace
4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4708 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The updated description of the AgentSpace.
4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4708 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale) SENSITIVE = [:description] include Aws::Structure end |
#locale ⇒ String
The updated locale for the AgentSpace, which determines the language used in agent responses.
4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4708 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The updated name of the AgentSpace.
4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4708 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :locale) SENSITIVE = [:description] include Aws::Structure end |