Class: Aws::DevOpsAgent::Types::UpdateAssetFileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateAssetFileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for updating an asset file
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset containing the file.
-
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset file update.
-
#content ⇒ Types::AssetFileBody
Updated file content.
-
#metadata ⇒ Hash, ...
Metadata fields to update.
-
#path ⇒ String
The path of the file within the asset to update.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6386 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset containing the file
6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6386 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset file update
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6386 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::AssetFileBody
Updated file content. If omitted, the existing content is unchanged.
6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6386 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash, ...
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6386 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path of the file within the asset to update
6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6386 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |