Class: Aws::DevOpsAgent::Types::UpdateAssetFileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for updating an asset file

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space containing the asset

Returns:

  • (String)


5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735

class UpdateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#asset_idString

The unique identifier of the asset containing the file

Returns:

  • (String)


5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735

class UpdateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier used for idempotent asset file update

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735

class UpdateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contentTypes::AssetFileBody

Updated file content. If omitted, the existing content is unchanged.



5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735

class UpdateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash, ...

Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735

class UpdateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path of the file within the asset to update

Returns:

  • (String)


5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735

class UpdateAssetFileRequest < Struct.new(
  :agent_space_id,
  :asset_id,
  :path,
  :content,
  :metadata,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end