Class: Aws::DevOpsAgent::Types::UpdateAssetFileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateAssetFileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for updating an asset file
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset containing the file.
-
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset file update.
-
#content ⇒ Types::AssetFileBody
Updated file content.
-
#metadata ⇒ Hash, ...
Metadata fields to update.
-
#path ⇒ String
The path of the file within the asset to update.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset containing the file
5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset file update
**A suitable default value is auto-generated.** You should normally not need to pass this option.
5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::AssetFileBody
Updated file content. If omitted, the existing content is unchanged.
5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash, ...
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path of the file within the asset to update
5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5735 class UpdateAssetFileRequest < Struct.new( :agent_space_id, :asset_id, :path, :content, :metadata, :client_token) SENSITIVE = [] include Aws::Structure end |