Class: Aws::DevOpsAgent::Types::UpdateAssetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateAssetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for updating an asset
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset.
-
#asset_id ⇒ String
The unique identifier of the asset to update.
-
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset update.
-
#content ⇒ Types::AssetContent
Optional content to set or replace.
-
#metadata ⇒ Hash, ...
Metadata fields to update.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the asset
5789 5790 5791 5792 5793 5794 5795 5796 5797 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5789 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The unique identifier of the asset to update
5789 5790 5791 5792 5793 5794 5795 5796 5797 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5789 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier used for idempotent asset update
**A suitable default value is auto-generated.** You should normally not need to pass this option.
5789 5790 5791 5792 5793 5794 5795 5796 5797 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5789 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::AssetContent
Optional content to set or replace. A single file adds or replaces one file; a zip replaces all files.
5789 5790 5791 5792 5793 5794 5795 5796 5797 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5789 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash, ...
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
5789 5790 5791 5792 5793 5794 5795 5796 5797 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5789 class UpdateAssetRequest < Struct.new( :agent_space_id, :asset_id, :metadata, :content, :client_token) SENSITIVE = [] include Aws::Structure end |