Class: Aws::DevOpsAgent::Types::UpdateBacklogTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsagent/types.rb

Overview

Request structure for updating a task

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier for the agent space containing the task

Returns:

  • (String)


4802
4803
4804
4805
4806
4807
4808
4809
# File 'lib/aws-sdk-devopsagent/types.rb', line 4802

class UpdateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :task_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Client-provided token for idempotent operations

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


4802
4803
4804
4805
4806
4807
4808
4809
# File 'lib/aws-sdk-devopsagent/types.rb', line 4802

class UpdateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :task_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the task to update

Returns:

  • (String)


4802
4803
4804
4805
4806
4807
4808
4809
# File 'lib/aws-sdk-devopsagent/types.rb', line 4802

class UpdateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :task_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_statusString

Updated task status

Returns:

  • (String)


4802
4803
4804
4805
4806
4807
4808
4809
# File 'lib/aws-sdk-devopsagent/types.rb', line 4802

class UpdateBacklogTaskRequest < Struct.new(
  :agent_space_id,
  :task_id,
  :task_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end