Class: Aws::DevOpsAgent::Types::UpdateGoalRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UpdateGoalRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Request structure for updating a goal
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier for the agent space containing the goal.
-
#client_token ⇒ String
Client-provided token for idempotent operations.
-
#evaluation_schedule ⇒ Types::GoalScheduleInput
Update goal schedule state.
-
#goal_id ⇒ String
The unique identifier of the goal to update.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier for the agent space containing the goal
4848 4849 4850 4851 4852 4853 4854 4855 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4848 class UpdateGoalRequest < Struct.new( :agent_space_id, :goal_id, :evaluation_schedule, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Client-provided token for idempotent operations
**A suitable default value is auto-generated.** You should normally not need to pass this option.
4848 4849 4850 4851 4852 4853 4854 4855 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4848 class UpdateGoalRequest < Struct.new( :agent_space_id, :goal_id, :evaluation_schedule, :client_token) SENSITIVE = [] include Aws::Structure end |
#evaluation_schedule ⇒ Types::GoalScheduleInput
Update goal schedule state
4848 4849 4850 4851 4852 4853 4854 4855 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4848 class UpdateGoalRequest < Struct.new( :agent_space_id, :goal_id, :evaluation_schedule, :client_token) SENSITIVE = [] include Aws::Structure end |
#goal_id ⇒ String
The unique identifier of the goal to update
4848 4849 4850 4851 4852 4853 4854 4855 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 4848 class UpdateGoalRequest < Struct.new( :agent_space_id, :goal_id, :evaluation_schedule, :client_token) SENSITIVE = [] include Aws::Structure end |