Class: Aws::DevOpsAgent::Types::UserMessageBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UserMessageBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
UserMessageBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserMessageBlock corresponding to the set member.
A block of content in a user message.
Direct Known Subclasses
Defined Under Namespace
Classes: Text, ToolResult, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
Text content from the user.
-
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ String
Text content from the user.
6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6867 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6867 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6867 6868 6869 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6867 def unknown @unknown end |