Class: Aws::DevOpsAgent::Types::UserMessageBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UserMessageBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
UserMessageBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserMessageBlock corresponding to the set member.
A block of content in a user message.
Direct Known Subclasses
Defined Under Namespace
Classes: Text, ToolResult, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
Text content from the user.
-
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ String
Text content from the user.
6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 6461 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6450 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 6461 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6450 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6450 6451 6452 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6450 def unknown @unknown end |