Class: Aws::DevOpsAgent::Types::UserMessageBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UserMessageBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
UserMessageBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserMessageBlock corresponding to the set member.
A block of content in a user message.
Direct Known Subclasses
Defined Under Namespace
Classes: Text, ToolResult, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
Text content from the user.
-
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ String
Text content from the user.
6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6163 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6163 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6163 6164 6165 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 6163 def unknown @unknown end |