Class: Aws::DevOpsAgent::Types::UserMessageBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::UserMessageBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Note:
UserMessageBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserMessageBlock corresponding to the set member.
A block of content in a user message.
Direct Known Subclasses
Defined Under Namespace
Classes: Text, ToolResult, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
Text content from the user.
-
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ String
Text content from the user.
5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5070 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#tool_result ⇒ Hash, ...
Tool execution result provided by the user.
5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5070 class UserMessageBlock < Struct.new( :text, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < UserMessageBlock; end class ToolResult < UserMessageBlock; end class Unknown < UserMessageBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5070 5071 5072 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5070 def unknown @unknown end |