Class: Aws::DevOpsAgent::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
The input fails to satisfy the constraints specified by the service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_list ⇒ Array<Types::ValidationExceptionField>
A list of specific failures encountered while validating the input.
-
#message ⇒ String
A summary of the validation failure.
Instance Attribute Details
#field_list ⇒ Array<Types::ValidationExceptionField>
A list of specific failures encountered while validating the input. A member can appear in this list more than once if it failed to satisfy multiple constraints.
5275 5276 5277 5278 5279 5280 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5275 class ValidationException < Struct.new( :message, :field_list) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A summary of the validation failure.
5275 5276 5277 5278 5279 5280 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5275 class ValidationException < Struct.new( :message, :field_list) SENSITIVE = [] include Aws::Structure end |