Class: Aws::DevOpsAgent::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
A standard error for input validation failures. This should be thrown by services when a member of the input structure falls outside of the modeled or documented constraints.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_list ⇒ Array<Types::ValidationExceptionField>
A list of specific failures encountered while validating the input.
-
#message ⇒ String
A summary of the validation failure.
Instance Attribute Details
#field_list ⇒ Array<Types::ValidationExceptionField>
A list of specific failures encountered while validating the input. A member can appear in this list more than once if it failed to satisfy multiple constraints.
5138 5139 5140 5141 5142 5143 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5138 class ValidationException < Struct.new( :message, :field_list) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A summary of the validation failure.
5138 5139 5140 5141 5142 5143 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5138 class ValidationException < Struct.new( :message, :field_list) SENSITIVE = [] include Aws::Structure end |