Class: Aws::DevOpsAgent::Types::ValidationExceptionField
- Inherits:
-
Struct
- Object
- Struct
- Aws::DevOpsAgent::Types::ValidationExceptionField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devopsagent/types.rb
Overview
Describes one specific validation failure for an input member.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A detailed description of the validation failure.
-
#path ⇒ String
A JSONPointer expression to the structure member whose value failed to satisfy the modeled constraints.
Instance Attribute Details
#message ⇒ String
A detailed description of the validation failure.
5158 5159 5160 5161 5162 5163 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5158 class ValidationExceptionField < Struct.new( :path, :message) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A JSONPointer expression to the structure member whose value failed to satisfy the modeled constraints.
5158 5159 5160 5161 5162 5163 |
# File 'lib/aws-sdk-devopsagent/types.rb', line 5158 class ValidationExceptionField < Struct.new( :path, :message) SENSITIVE = [] include Aws::Structure end |